@@ -1,23 +1,40 @@
 /**********************************************************************
- * $Id: MinimumDiameter.cpp,v 1.8 2004/11/04 19:08:06 strk Exp $
+ * $Id: MinimumDiameter.cpp 1986 2007-06-08 15:27:42Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
+ * Copyright (C) 2005 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
+ **********************************************************************
+ * 
+ * TODO:
+ * 	- avoid heap allocation for LineSegment and Coordinate
+ *
  **********************************************************************/
 
-#include <geos/geosAlgorithm.h>
-#include <stdio.h>
+#include <geos/algorithm/MinimumDiameter.h>
+#include <geos/algorithm/ConvexHull.h>
+#include <geos/geom/Geometry.h>
+#include <geos/geom/LineSegment.h>
+#include <geos/geom/Polygon.h>
+#include <geos/geom/LineString.h>
+#include <geos/geom/CoordinateSequenceFactory.h>
+#include <geos/geom/GeometryFactory.h>
+#include <geos/geom/CoordinateSequence.h>
+
 #include <typeinfo>
 
+using namespace geos::geom;
+
 namespace geos {
+namespace algorithm { // geos.algorithm
 
 /**
  * Computes the minimum diameter of a Geometry.
@@ -128,11 +145,13 @@ MinimumDiameter::getDiameter()
 	// return empty linestring if no minimum width calculated
 	if (minWidthPt==NULL)
 		return inputGeom->getFactory()->createLineString(NULL);
-	Coordinate* basePt=minBaseSeg->project(*minWidthPt);
+
+	Coordinate basePt;
+	minBaseSeg->project(*minWidthPt, basePt);
+
 	CoordinateSequence* cl=inputGeom->getFactory()->getCoordinateSequenceFactory()->create(NULL);
-	cl->add(*basePt);
+	cl->add(basePt);
 	cl->add(*minWidthPt);
-	delete basePt;
 	return inputGeom->getFactory()->createLineString(cl);
 }
 
@@ -165,22 +184,29 @@ MinimumDiameter::computeWidthConvex(const Geometry *geom)
 		pts=geom->getCoordinates();
 
 	// special cases for lines or points or degenerate rings
-	if (pts->getSize()==0) {
-		minWidth=0.0;
-		minWidthPt=NULL;
-		minBaseSeg=NULL;
-	} else if (pts->getSize()==1) {
-		minWidth = 0.0;
-		minWidthPt=new Coordinate(pts->getAt(0));
-		minBaseSeg->p0=pts->getAt(0);
-		minBaseSeg->p1=pts->getAt(0);
-	} else if (pts->getSize()==2 || pts->getSize()==3) {
-		minWidth = 0.0;
-		minWidthPt=new Coordinate(pts->getAt(0));
-		minBaseSeg->p0=pts->getAt(0);
-		minBaseSeg->p1=pts->getAt(1);
-	} else
-		computeConvexRingMinDiameter(pts);
+	switch(pts->getSize())
+	{
+		case 0:
+			minWidth=0.0;
+			minWidthPt=NULL;
+			minBaseSeg=NULL;
+			break;
+		case 1:
+			minWidth = 0.0;
+			minWidthPt=new Coordinate(pts->getAt(0));
+			minBaseSeg->p0=pts->getAt(0);
+			minBaseSeg->p1=pts->getAt(0);
+			break;
+		case 2:
+		case 3:
+			minWidth = 0.0;
+			minWidthPt=new Coordinate(pts->getAt(0));
+			minBaseSeg->p0=pts->getAt(0);
+			minBaseSeg->p1=pts->getAt(1);
+			break;
+		default:
+			computeConvexRingMinDiameter(pts);
+	}
 	delete pts; 
 }
 
@@ -195,30 +221,33 @@ void
 MinimumDiameter::computeConvexRingMinDiameter(const CoordinateSequence* pts)
 {
 	minWidth=DoubleInfinity;
-	int currMaxIndex=1;
-	LineSegment* seg=new LineSegment();
+	unsigned int currMaxIndex=1;
+	LineSegment seg;
+
 	// compute the max distance for all segments in the ring, and pick the minimum
-	for (int i = 0; i < pts->getSize()-1; i++) {
-		seg->p0=pts->getAt(i);
-		seg->p1=pts->getAt(i + 1);
-		currMaxIndex=findMaxPerpDistance(pts, seg, currMaxIndex);
+	const std::size_t npts=pts->getSize();
+	for (std::size_t i=1; i<npts; ++i) {
+		seg.p0=pts->getAt(i-1);
+		seg.p1=pts->getAt(i);
+		currMaxIndex=findMaxPerpDistance(pts, &seg, currMaxIndex);
 	}
-	delete seg;
 }
 
-int
-MinimumDiameter::findMaxPerpDistance(const CoordinateSequence *pts, LineSegment* seg, int startIndex)
+unsigned int
+MinimumDiameter::findMaxPerpDistance(const CoordinateSequence *pts,
+		LineSegment* seg, unsigned int startIndex)
 {
 	double maxPerpDistance=seg->distancePerpendicular(pts->getAt(startIndex));
 	double nextPerpDistance = maxPerpDistance;
-	int maxIndex = startIndex;
-	int nextIndex = maxIndex;
+	unsigned int maxIndex = startIndex;
+	unsigned int nextIndex = maxIndex;
 	while (nextPerpDistance >= maxPerpDistance) {
 		maxPerpDistance = nextPerpDistance;
 		maxIndex=nextIndex;
 		nextIndex=getNextIndex(pts, maxIndex);
 		nextPerpDistance = seg->distancePerpendicular(pts->getAt(nextIndex));
 	}
+
 	// found maximum width for this segment - update global min dist if appropriate
 	if (maxPerpDistance < minWidth) {
 		minPtIndex = maxIndex;
@@ -233,45 +262,23 @@ MinimumDiameter::findMaxPerpDistance(const CoordinateSequence *pts, LineSegment*
 	return maxIndex;
 }
 
-int
-MinimumDiameter::getNextIndex(const CoordinateSequence *pts, int index)
+unsigned int
+MinimumDiameter::getNextIndex(const CoordinateSequence *pts,
+	unsigned int index)
 {
-	index++;
-	if (index >= pts->getSize()) index = 0;
+	if (++index >= pts->getSize()) index = 0;
 	return index;
 }
 
-} //namespace
+} // namespace geos.algorithm
+} // namespace geos
 
 /**********************************************************************
- * $Log: MinimumDiameter.cpp,v $
- * Revision 1.8  2004/11/04 19:08:06  strk
- * Cleanups, initializers list, profiling.
- *
- * Revision 1.7  2004/07/08 19:34:49  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.6  2004/07/02 13:28:26  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.5  2004/05/05 13:08:01  strk
- * Leaks fixed, explicit allocations/deallocations reduced.
- *
- * Revision 1.4  2004/04/20 13:24:15  strk
- * More leaks removed.
- *
- * Revision 1.3  2004/04/20 12:47:57  strk
- * MinimumDiameter leaks plugged.
- *
- * Revision 1.2  2004/04/20 10:14:20  strk
- * Memory leaks removed.
- *
- * Revision 1.1  2004/03/17 02:00:33  ybychkov
- * "Algorithm" upgraded to JTS 1.4
- *
+ * $Log$
+ * Revision 1.15  2006/03/21 11:12:23  strk
+ * Cleanups: headers inclusion and Log section
  *
+ * Revision 1.14  2006/03/09 16:46:45  strk
+ * geos::geom namespace definition, first pass at headers split
  **********************************************************************/
 
