@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Geometry.cpp 2040 2007-12-13 16:09:25Z mloskot $
+ * $Id: Geometry.cpp 2252 2009-01-21 22:18:37Z pramsey $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -422,9 +422,10 @@ Geometry::contains(const Geometry *g) const
 	if (isRectangle()) {
 		return predicate::RectangleContains::contains((Polygon&)*this, *g);
 	}
-	if (g->isRectangle()) {
-		return predicate::RectangleContains::contains((const Polygon&)*g, *this);
-	}
+	// Incorrect: contains is not commutative
+	//if (g->isRectangle()) {
+	//	return predicate::RectangleContains::contains((const Polygon&)*g, *this);
+	//}
 
 	IntersectionMatrix *im=relate(g);
 	bool res=im->isContains();
@@ -473,8 +474,6 @@ IntersectionMatrix*
 Geometry::relate(const Geometry *other) const
 	//throw(IllegalArgumentException *)
 {
-	checkNotGeometryCollection(this);
-	checkNotGeometryCollection(other);
 	return RelateOp::relate(this, other);
 }
 
@@ -526,8 +525,6 @@ Geometry::convexHull() const
 Geometry*
 Geometry::intersection(const Geometry *other) const
 {
-	checkNotGeometryCollection(this);
-	checkNotGeometryCollection(other);
 	return OverlayOp::overlayOp(this, other, OverlayOp::opINTERSECTION);
 }
 
@@ -535,9 +532,6 @@ Geometry*
 Geometry::Union(const Geometry *other) const
 	//throw(TopologyException *, IllegalArgumentException *)
 {
-	checkNotGeometryCollection(this);
-	checkNotGeometryCollection(other);
-
 	Geometry *out = NULL;
 
 #ifdef SHORTCIRCUIT_PREDICATES
@@ -580,16 +574,12 @@ Geometry*
 Geometry::difference(const Geometry *other) const
 	//throw(IllegalArgumentException *)
 {
-	checkNotGeometryCollection(this);
-	checkNotGeometryCollection(other);
 	return OverlayOp::overlayOp(this, other, OverlayOp::opDIFFERENCE);
 }
 
 Geometry*
 Geometry::symDifference(const Geometry *other) const
 {
-	checkNotGeometryCollection(this);
-	checkNotGeometryCollection(other);
 	return OverlayOp::overlayOp(this, other, OverlayOp::opSYMDIFFERENCE);
 }
 
