@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: GeometryComponentFilter.cpp 1820 2006-09-06 16:54:23Z mloskot $
+ * $Id: GeometryComponentFilter.cpp 2127 2008-05-20 21:25:21Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -18,6 +18,7 @@
 
 #include <geos/geom/GeometryComponentFilter.h>
 #include <geos/geom/Geometry.h>
+#include <geos/util.h>
 
 namespace geos {
 namespace geom { // geos::geom
@@ -28,6 +29,7 @@ void GeometryComponentFilter::filter_rw(Geometry *geom) {
 
 void GeometryComponentFilter::filter_ro(const Geometry *geom)
 {
+    UNREFERENCED_PARAMETER(geom);
 	//assert(0);
 }
 
