@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Location.cpp,v 1.9.2.1 2005/05/23 18:41:51 strk Exp $
+ * $Id: Location.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,28 +11,17 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: Location.cpp,v $
- * Revision 1.9.2.1  2005/05/23 18:41:51  strk
- * Replaced sprintf uses with ostringstream
- *
- * Revision 1.9  2004/07/02 13:28:26  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.8  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- *
  **********************************************************************/
 
+#include <geos/geom/Location.h>
+#include <geos/util/IllegalArgumentException.h>
 
 #include <sstream>
-#include <geos/geom.h>
-#include <geos/util.h>
+
+using namespace std;
 
 namespace geos {
+namespace geom { // geos::geom
 
 /**
  *  Converts the location value to a location symbol, for example, <code>EXTERIOR => 'e'</code>.
@@ -53,8 +42,19 @@ char Location::toLocationSymbol(int locationValue) {
 		default:
 			ostringstream s;
 			s<<"Unknown location value: "<<locationValue;
-			throw new IllegalArgumentException(s.str());
+			throw util::IllegalArgumentException(s.str());
 	}
 }
-}
 
+} // namespace geos::geom
+} // namespace geos
+
+/**********************************************************************
+ * $Log$
+ * Revision 1.15  2006/03/22 16:58:34  strk
+ * Removed (almost) all inclusions of geom.h.
+ * Removed obsoleted .cpp files.
+ * Fixed a bug in WKTReader not using the provided CoordinateSequence
+ * implementation, optimized out some memory allocations.
+ *
+ **********************************************************************/
