@@ -1,121 +1,82 @@
 /**********************************************************************
- * $Id: EdgeEndStar.cpp,v 1.9 2004/12/08 13:54:43 strk Exp $
+ * $Id: EdgeEndStar.cpp 2062 2007-12-21 20:39:38Z benjubb $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
+ * Copyright (C) 2005 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
+ **********************************************************************
+ *
+ * Last port: geomgraph/EdgeEndStar.java rev. 1.4 (JTS-1.7)
+ *
  **********************************************************************/
 
-#include <geos/geomgraph.h>
-#include <geos/util.h>
+#include <geos/util/TopologyException.h>
+#include <geos/geomgraph/EdgeEndStar.h>
+#include <geos/algorithm/locate/SimplePointInAreaLocator.h>
+#include <geos/geom/Location.h>
+#include <geos/geomgraph/Label.h>
+#include <geos/geomgraph/Position.h>
+#include <geos/geomgraph/GeometryGraph.h>
 
-#define DEBUG 0
+#include <cassert>
+#include <string>
+#include <vector>
+
+#ifndef GEOS_DEBUG
+#define GEOS_DEBUG 0
+#endif
+
+//using namespace std;
+//using namespace geos::algorithm;
+using namespace geos::geom;
 
 namespace geos {
+namespace geomgraph { // geos.geomgraph
 
-EdgeEndStar::EdgeEndStar(){
+/*public*/
+EdgeEndStar::EdgeEndStar()
+	:
+	edgeMap()
+{
 	ptInAreaLocation[0]=Location::UNDEF;
 	ptInAreaLocation[1]=Location::UNDEF;
-	edgeMap=new map<EdgeEnd*,void*,EdgeEndLT>();
-	edgeList=NULL;
 }
 
-EdgeEndStar::~EdgeEndStar(){
-//	map<EdgeEnd*,void*,EdgeEndLT>::iterator	it=edgeMap->begin();
-//	for (;it!=edgeMap->end();it++) {
-//		EdgeEnd *ee=(EdgeEnd*) it->second;
-////		void *ee= it->second;
-//		delete ee;
-//	}
-	delete edgeMap;
-	delete edgeList;
-}
-
-void EdgeEndStar::insert(EdgeEnd *e){
-	delete e;
-}
-
-/**
- * Insert an EdgeEnd into the map, and clear the edgeList cache,
- * since the list of edges has now changed
- */
-void EdgeEndStar::insertEdgeEnd(EdgeEnd *e,void* obj){
-	edgeMap->insert(pair<EdgeEnd*,void*>(e,obj));
-//	(*edgeMap)[e]=obj;
-	delete edgeList;
-	edgeList=NULL;  // edge list has changed - clear the cache
-}
-
-/**
- * @return the coordinate for the node this star is based at
- */
+/*public*/
 Coordinate&
 EdgeEndStar::getCoordinate()
 {
-	if (getEdges()->size()==0)
-		return *(new Coordinate(DoubleNotANumber,DoubleNotANumber,DoubleNotANumber));
-	vector<EdgeEnd*>::iterator it=getIterator();
+	static Coordinate nullCoord(DoubleNotANumber, DoubleNotANumber, DoubleNotANumber);
+	if (edgeMap.size()==0) return nullCoord;
+
+	EdgeEndStar::iterator it=begin();
 	EdgeEnd *e=*it;
+	assert(e);
 	return e->getCoordinate();
 }
 
-int EdgeEndStar::getDegree(){
-	return (int)edgeMap->size();
-}
-
-vector<EdgeEnd*>*
-EdgeEndStar::getEdges()
-{
-	map<EdgeEnd*,void*,EdgeEndLT>::iterator mapIter;
-	if (edgeList==NULL) {
-		edgeList=new vector<EdgeEnd*>();
-		for(mapIter=edgeMap->begin();mapIter!=edgeMap->end();mapIter++) {
-//			edgeList->push_back(mapIter->first);
-			EdgeEnd *e=(EdgeEnd*) mapIter->second;
-			edgeList->push_back(e);
-		}
-	}
-//cout << endl << "edgeList:" << endl;
-//for(int i=0;i<(int)edgeList->size();i++) {
-//	cout << endl << (*edgeList)[i]->print() << endl;
-//}
-	return edgeList;
-}
-
-vector<EdgeEnd*>::iterator
-EdgeEndStar::getIterator()
-{
-	return getEdges()->begin();
-}
-
+/*public*/
 EdgeEnd*
 EdgeEndStar::getNextCW(EdgeEnd *ee)
 {
-	getEdges();
-	int i=0;
-	for(unsigned int j=0;j<edgeList->size();j++)
-	{
-		//if (ee->compareTo( *(edgeList->at(j)))==0) 
-		if (ee->compareTo((*edgeList)[j])==0)
-		{
-			i=j;
-			break;
-		}
-	}
-	int iNextCW=i-1;
-	if (i==0) iNextCW=(int)edgeList->size()-1;
-	return (*edgeList)[iNextCW];
+	EdgeEndStar::iterator it=find(ee);
+	if ( it==end() ) return NULL;
+	if ( it==begin() ) { it=end(); --it; }
+	else --it;
+	return *it;
 }
 
+/*public*/
 void
-EdgeEndStar::computeLabelling(vector<GeometryGraph*> *geom)
+EdgeEndStar::computeLabelling(std::vector<GeometryGraph*> *geom)
 	//throw(TopologyException *)
 {
 	computeEdgeEndLabels();
@@ -166,20 +127,29 @@ EdgeEndStar::computeLabelling(vector<GeometryGraph*> *geom)
 	 * resolution.
 	 */
 	bool hasDimensionalCollapseEdge[2]={false,false};
-	vector<EdgeEnd*>::iterator it;
-	for (it=getIterator();it<edgeList->end();it++) {
+
+	EdgeEndStar::iterator endIt=end();
+	for (EdgeEndStar::iterator it=begin(); it!=endIt; ++it)
+	{
 		EdgeEnd *e=*it;
+		assert(e);
 		Label *label=e->getLabel();
+		assert(label);
 		for(int geomi=0; geomi<2; geomi++)
 		{
 			if (label->isLine(geomi) && label->getLocation(geomi)==Location::BOUNDARY)
 				hasDimensionalCollapseEdge[geomi]=true;
 		}
 	}
-	for (it=getIterator();it<edgeList->end();it++) {
+
+	for (EdgeEndStar::iterator it=begin(); it!=end(); ++it)
+	{
 		EdgeEnd *e=*it;
+		assert(e);
 		Label *label=e->getLabel();
-		for(int geomi=0;geomi<2;geomi++){
+		assert(label);
+		for(int geomi=0; geomi<2; ++geomi)
+		{
 			if (label->isAnyNull(geomi)) {
 				int loc=Location::UNDEF;
 				if (hasDimensionalCollapseEdge[geomi]){
@@ -194,60 +164,84 @@ EdgeEndStar::computeLabelling(vector<GeometryGraph*> *geom)
 	}
 }
 
+/*private*/
 void
 EdgeEndStar::computeEdgeEndLabels()
 {
 	// Compute edge label for each EdgeEnd
-	vector<EdgeEnd*>::iterator it;
-	for (it=getIterator(); it<edgeList->end(); it++)
+	for (EdgeEndStar::iterator it=begin(); it!=end(); ++it)
 	{
 		EdgeEnd *e=*it;
+		assert(e);
 		e->computeLabel();
 	}
 }
 
+/*public*/
 int
-EdgeEndStar::getLocation(int geomIndex,Coordinate& p,vector<GeometryGraph*> *geom)
+EdgeEndStar::getLocation(int geomIndex,
+	const Coordinate& p, std::vector<GeometryGraph*> *geom)
 {
 	// compute location only on demand
 	if (ptInAreaLocation[geomIndex]==Location::UNDEF)
 	{
-        	ptInAreaLocation[geomIndex]=SimplePointInAreaLocator::locate(p,(*geom)[geomIndex]->getGeometry());
+		ptInAreaLocation[geomIndex]=algorithm::locate::SimplePointInAreaLocator::locate(p,
+				(*geom)[geomIndex]->getGeometry());
 	}
 	return ptInAreaLocation[geomIndex];
 }
 
-bool EdgeEndStar::isAreaLabelsConsistent(){
+/*public*/
+bool
+EdgeEndStar::isAreaLabelsConsistent()
+{
 	computeEdgeEndLabels();
 	return checkAreaLabelsConsistent(0);
 }
 
-bool EdgeEndStar::checkAreaLabelsConsistent(int geomIndex){
+/*private*/
+bool
+EdgeEndStar::checkAreaLabelsConsistent(int geomIndex)
+{
 	// Since edges are stored in CCW order around the node,
-	// As we move around the ring we move from the right to the left side of the edge
-	vector<EdgeEnd*> *edges=getEdges();
+	// As we move around the ring we move from the right to
+	// the left side of the edge
+
 	// if no edges, trivially consistent
-	if (edges->size()<=0)
-		return true;
+	if (edgeMap.size()==0) return true;
+
 	// initialize startLoc to location of last L side (if any)
-	int lastEdgeIndex=(int)edges->size()-1;
-	Label *startLabel=((*edgeList)[lastEdgeIndex])->getLabel();
-	int startLoc=startLabel->getLocation(geomIndex,Position::LEFT);
-	Assert::isTrue(startLoc!=Location::UNDEF, "Found unlabelled area edge");
+	EdgeEndStar::reverse_iterator it=rbegin();
+
+	assert(*it);
+	Label *startLabel=(*it)->getLabel();
+	int startLoc=startLabel->getLocation(geomIndex, Position::LEFT);
+
+	// Found unlabelled area edge
+	assert(startLoc!=Location::UNDEF);
+
 	int currLoc=startLoc;
-	for (vector<EdgeEnd*>::iterator it=getIterator();it<edgeList->end();it++) {
+
+	for (EdgeEndStar::iterator it=begin(), itEnd=end(); it!=itEnd; ++it)
+	{
 		EdgeEnd *e=*it;
+		assert(e);
 		Label *eLabel=e->getLabel();
+		assert(eLabel);
+
 		// we assume that we are only checking a area
-		Assert::isTrue(eLabel->isArea(geomIndex), "Found non-area edge");
-		int leftLoc=eLabel->getLocation(geomIndex,Position::LEFT);
-		int rightLoc=eLabel->getLocation(geomIndex,Position::RIGHT);
+
+		// Found non-area edge
+		assert(eLabel->isArea(geomIndex));
+
+		int leftLoc=eLabel->getLocation(geomIndex, Position::LEFT);
+		int rightLoc=eLabel->getLocation(geomIndex, Position::RIGHT);
 		// check that edge is really a boundary between inside and outside!
 		if (leftLoc==rightLoc) {
 			return false;
 		}
 		// check side location conflict
-		//Assert.isTrue(rightLoc == currLoc, "side location conflict " + locStr);
+		//assert(rightLoc == currLoc); // "side location conflict " + locStr);
 		if (rightLoc!=currLoc) {
 			return false;
 		}
@@ -256,6 +250,7 @@ bool EdgeEndStar::checkAreaLabelsConsistent(int geomIndex){
 	return true;
 }
 
+/*public*/
 void
 EdgeEndStar::propagateSideLabels(int geomIndex)
 	//throw(TopologyException *)
@@ -263,24 +258,34 @@ EdgeEndStar::propagateSideLabels(int geomIndex)
 	// Since edges are stored in CCW order around the node,
 	// As we move around the ring we move from the right to the
 	// left side of the edge
-	int startLoc=Location::UNDEF ;
+	int startLoc=Location::UNDEF;
+
+	EdgeEndStar::iterator beginIt=begin();
+	EdgeEndStar::iterator endIt=end();
+	EdgeEndStar::iterator it;
 
 	// initialize loc to location of last L side (if any)
-	vector<EdgeEnd*>::iterator it;
-	for (it=getIterator();it<edgeList->end();it++)
+	for (EdgeEndStar::iterator it=beginIt; it!=endIt; ++it)
 	{
 		EdgeEnd *e=*it;
+		assert(e);
 		Label *label=e->getLabel();
+		assert(label);
 		if (label->isArea(geomIndex) &&
 			label->getLocation(geomIndex,Position::LEFT)!=Location::UNDEF)
 			startLoc=label->getLocation(geomIndex,Position::LEFT);
 	}
+
 	// no labelled sides found, so no labels to propagate
 	if (startLoc==Location::UNDEF) return;
+
 	int currLoc=startLoc;
-	for (it=getIterator();it<edgeList->end();it++) {
+	for (it=beginIt; it!=endIt; ++it)
+	{
 		EdgeEnd *e=*it;
+		assert(e);
 		Label *label=e->getLabel();
+		assert(label);
 		// set null ON values to be in current location
 		if (label->getLocation(geomIndex,Position::ON)==Location::UNDEF)
 			label->setLocation(geomIndex,Position::ON,currLoc);
@@ -288,14 +293,21 @@ EdgeEndStar::propagateSideLabels(int geomIndex)
 		// if (label.isArea())  //ORIGINAL
 		if (label->isArea(geomIndex))
 		{
-			int leftLoc=label->getLocation(geomIndex,Position::LEFT);
-			int rightLoc=label->getLocation(geomIndex,Position::RIGHT);
-			// if there is a right location, that is the next location to propagate
+			int leftLoc=label->getLocation(geomIndex,
+				Position::LEFT);
+
+			int rightLoc=label->getLocation(geomIndex,
+				Position::RIGHT);
+
+			// if there is a right location, that is the next
+			// location to propagate
 			if (rightLoc!=Location::UNDEF) {
 				if (rightLoc!=currLoc)
-					throw new TopologyException("side location conflict",&(e->getCoordinate()));
+					throw util::TopologyException("side location conflict",
+						e->getCoordinate());
 				if (leftLoc==Location::UNDEF) {
-					Assert::shouldNeverReachHere("found single null side (at " + (e->getCoordinate()).toString() + ")");
+					// found single null side at e->getCoordinate()
+					assert(0);
 				}
 				currLoc=leftLoc;
 			} else {
@@ -310,9 +322,10 @@ EdgeEndStar::propagateSideLabels(int geomIndex)
 				 * Assign both sides to be the current
 				 * location.
 				 */
-				Assert::isTrue(label->getLocation(geomIndex,
-					Position::LEFT)==Location::UNDEF,
-					"found single null side");
+				// found single null side
+				assert(label->getLocation(geomIndex,
+					Position::LEFT)==Location::UNDEF);
+
 				label->setLocation(geomIndex,Position::RIGHT,
 					currLoc);
 				label->setLocation(geomIndex,Position::LEFT,
@@ -322,32 +335,98 @@ EdgeEndStar::propagateSideLabels(int geomIndex)
 	}
 }
 
-int EdgeEndStar::findIndex(EdgeEnd *eSearch){
-	getIterator();   // force edgelist to be computed
-	for (unsigned int i=0; i<edgeList->size(); i++ ) {
-		EdgeEnd *e=(*edgeList)[i];
-//		if (e->compareTo(eSearch)) return i;
-		if (e==eSearch) return i;
-	}
-	return -1;
-}
-
-string
+/*public*/
+std::string
 EdgeEndStar::print()
 {
-	string out="EdgeEndStar:   " + getCoordinate().toString()+"\n";
-	for (vector<EdgeEnd*>::iterator it=getIterator();it<edgeList->end();it++)
+	std::string out="EdgeEndStar:   " + getCoordinate().toString()+"\n";
+	for (EdgeEndStar::iterator it=begin(), itEnd=end(); it!=itEnd; ++it)
 	{
 		EdgeEnd *e=*it;
+		assert(e);
 		out+=e->print();
 	}
 	return out;
 }
 
-}
+} // namespace geos.geomgraph
+} // namespace geos
 
 /**********************************************************************
- * $Log: EdgeEndStar.cpp,v $
+ * $Log$
+ * Revision 1.21  2006/04/04 13:35:55  strk
+ * Port info, assertion checking, indentation
+ *
+ * Revision 1.20  2006/03/23 15:10:29  strk
+ * Dropped by-pointer TopologyException constructor, various small cleanups
+ *
+ * Revision 1.19  2006/03/15 17:16:29  strk
+ * streamlined headers inclusion
+ *
+ * Revision 1.18  2006/03/09 16:46:47  strk
+ * geos::geom namespace definition, first pass at headers split
+ *
+ * Revision 1.17  2006/03/06 19:40:46  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
+ *
+ * Revision 1.16  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.15  2006/03/02 12:12:00  strk
+ * Renamed DEBUG macros to GEOS_DEBUG, all wrapped in #ifndef block to allow global override (bug#43)
+ *
+ * Revision 1.14  2006/02/19 19:46:49  strk
+ * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
+ *
+ * Revision 1.13  2006/02/09 15:52:47  strk
+ * GEOSException derived from std::exception; always thrown and cought by const ref.
+ *
+ * Revision 1.12  2005/12/07 20:51:47  strk
+ * removed dead code
+ *
+ * Revision 1.11  2005/11/29 00:48:35  strk
+ * Removed edgeList cache from EdgeEndRing. edgeMap is enough.
+ * Restructured iterated access by use of standard ::iterator abstraction
+ * with scoped typedefs.
+ *
+ * Revision 1.10  2005/11/21 16:03:20  strk
+ *
+ * Coordinate interface change:
+ *         Removed setCoordinate call, use assignment operator
+ *         instead. Provided a compile-time switch to
+ *         make copy ctor and assignment operators non-inline
+ *         to allow for more accurate profiling.
+ *
+ * Coordinate copies removal:
+ *         NodeFactory::createNode() takes now a Coordinate reference
+ *         rather then real value. This brings coordinate copies
+ *         in the testLeaksBig.xml test from 654818 to 645991
+ *         (tested in 2.1 branch). In the head branch Coordinate
+ *         copies are 222198.
+ *         Removed useless coordinate copies in ConvexHull
+ *         operations
+ *
+ * STL containers heap allocations reduction:
+ *         Converted many containers element from
+ *         pointers to real objects.
+ *         Made some use of .reserve() or size
+ *         initialization when final container size is known
+ *         in advance.
+ *
+ * Stateless classes allocations reduction:
+ *         Provided ::instance() function for
+ *         NodeFactories, to avoid allocating
+ *         more then one (they are all
+ *         stateless).
+ *
+ * HCoordinate improvements:
+ *         Changed HCoordinate constructor by HCoordinates
+ *         take reference rather then real objects.
+ *         Changed HCoordinate::intersection to avoid
+ *         a new allocation but rather return into a provided
+ *         storage. LineIntersector changed to reflect
+ *         the above change.
+ *
  * Revision 1.9  2004/12/08 13:54:43  strk
  * gcc warnings checked and fixed, general cleanups.
  *
