@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Quadrant.cpp,v 1.2.2.1 2005/05/23 18:41:51 strk Exp $
+ * $Id: Quadrant.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,30 +11,20 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: Quadrant.cpp,v $
- * Revision 1.2.2.1  2005/05/23 18:41:51  strk
- * Replaced sprintf uses with ostringstream
- *
- * Revision 1.2  2004/07/02 13:28:26  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.1  2004/03/19 09:48:45  ybychkov
- * "geomgraph" and "geomgraph/indexl" upgraded to JTS 1.4
- *
- * Revision 1.10  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- *
  **********************************************************************/
 
-
 #include <sstream>
-#include <geos/geomgraph.h>
+
+#include <geos/geomgraph/Quadrant.h>
+#include <geos/util/IllegalArgumentException.h>
+
+#include <geos/geom/Coordinate.h>
+
+using namespace std;
+using namespace geos::geom;
 
 namespace geos {
+namespace geomgraph { // geos.geomgraph
 
 /**
 * Returns the quadrant of a directed line segment (specified as x and y
@@ -45,7 +35,7 @@ int Quadrant::quadrant(double dx, double dy) {
 		ostringstream s;
 		s<<"Cannot compute the quadrant for point ";
 		s<<"("<<dx<<","<<dy<<")"<<endl;
-		throw new IllegalArgumentException(s.str());
+		throw util::IllegalArgumentException(s.str());
 	}
 	if (dx >= 0) {
 		if (dy >= 0)
@@ -67,7 +57,9 @@ int Quadrant::quadrant(const Coordinate& p0, const Coordinate& p1) {
 	double dx=p1.x-p0.x;
 	double dy=p1.y-p0.y;
 	if (dx==0.0 && dy==0.0)
-		throw new IllegalArgumentException("Cannot compute the quadrant for two identical points " + p0.toString());
+	{
+		throw util::IllegalArgumentException("Cannot compute the quadrant for two identical points " + p0.toString());
+	}
 	return quadrant(dx, dy);
 }
 
@@ -119,5 +111,48 @@ bool Quadrant::isInHalfPlane(int quad, int halfPlane){
 bool Quadrant::isNorthern(int quad) {
 	return quad==0 || quad==1;
 }
-}
+
+} // namespace geos.geomgraph
+} // namespace geos
+
+/**********************************************************************
+ * $Log$
+ * Revision 1.10  2006/03/15 17:16:29  strk
+ * streamlined headers inclusion
+ *
+ * Revision 1.9  2006/03/09 16:46:47  strk
+ * geos::geom namespace definition, first pass at headers split
+ *
+ * Revision 1.8  2006/03/06 19:40:46  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
+ *
+ * Revision 1.7  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.6  2006/02/19 19:46:49  strk
+ * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
+ *
+ * Revision 1.5  2006/02/09 15:52:47  strk
+ * GEOSException derived from std::exception; always thrown and cought by const ref.
+ *
+ * Revision 1.4  2005/02/05 05:44:47  strk
+ * Changed geomgraph nodeMap to use Coordinate pointers as keys, reduces
+ * lots of other Coordinate copies.
+ *
+ * Revision 1.3  2005/01/28 09:47:51  strk
+ * Replaced sprintf uses with ostringstream.
+ *
+ * Revision 1.2  2004/07/02 13:28:26  strk
+ * Fixed all #include lines to reflect headers layout change.
+ * Added client application build tips in README.
+ *
+ * Revision 1.1  2004/03/19 09:48:45  ybychkov
+ * "geomgraph" and "geomgraph/indexl" upgraded to JTS 1.4
+ *
+ * Revision 1.10  2003/11/07 01:23:42  pramsey
+ * Add standard CVS headers licence notices and copyrights to all cpp and h
+ * files.
+ *
+ *
+ **********************************************************************/
 
