@@ -1,10 +1,11 @@
 /**********************************************************************
- * $Id: SegmentIntersector.cpp,v 1.7 2004/11/23 19:53:06 strk Exp $
+ * $Id: SegmentIntersector.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
+ * Copyright (C) 2005 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
@@ -14,13 +15,33 @@
  **********************************************************************/
 
 
-#include <geos/geomgraphindex.h>
-#include <math.h>
+#include <vector>
+
+#include <geos/geomgraph/index/SegmentIntersector.h>
+#include <geos/geomgraph/Edge.h>
+#include <geos/geomgraph/Node.h>
+#include <geos/algorithm/LineIntersector.h>
+#include <geos/geom/Coordinate.h>
+#include <geos/geom/CoordinateSequence.h>
+
+#ifndef GEOS_DEBUG
+#define GEOS_DEBUG 0
+#endif
 
 #define DEBUG_INTERSECT 0
-#define DEBUG 0
+
+#if GEOS_DEBUG || DEBUG_INTERSECT
+#include <iostream>
+#endif
+
+using namespace std;
+using namespace geos::geom;
 
 namespace geos {
+namespace geomgraph { // geos.geomgraph
+namespace index { // geos.geomgraph.index
+
+using namespace geos::algorithm;
 
 bool
 SegmentIntersector::isAdjacentSegments(int i1,int i2)
@@ -28,48 +49,12 @@ SegmentIntersector::isAdjacentSegments(int i1,int i2)
 	return abs(i1-i2)==1;
 }
 
-SegmentIntersector::SegmentIntersector()
-{
-	hasIntersectionVar=false;
-	hasProper=false;
-	hasProperInterior=false;
-	numIntersections=0;
-	numTests=0;
-	bdyNodes=NULL;
-}
-
-SegmentIntersector::~SegmentIntersector()
-{
-	if (bdyNodes!=NULL) {
-		for(int i=0;i<(int)bdyNodes->size();i++) {
-			delete (*bdyNodes)[i];
-		}
-		delete bdyNodes;
-	}
-}
-
-SegmentIntersector::SegmentIntersector(LineIntersector *newLi,bool newIncludeProper,bool newRecordIsolated)
-{
-	hasIntersectionVar=false;
-	hasProper=false;
-	hasProperInterior=false;
-	numIntersections=0;
-	numTests=0;
-
-	li=newLi;
-	includeProper=newIncludeProper;
-	recordIsolated=newRecordIsolated;
-	bdyNodes=NULL;
-}
-
 void
-SegmentIntersector::setBoundaryNodes(vector<Node*> *bdyNodes0,vector<Node*> *bdyNodes1)
+SegmentIntersector::setBoundaryNodes(vector<Node*> *bdyNodes0,
+	vector<Node*> *bdyNodes1)
 {
-	if (bdyNodes==NULL)
-		bdyNodes=new vector<vector<Node*>*>();
-	bdyNodes->resize(2);
-	*(bdyNodes->begin())=bdyNodes0;
-	*(bdyNodes->begin()+1)=bdyNodes1;
+	bdyNodes[0]=bdyNodes0;
+	bdyNodes[1]=bdyNodes1;
 }
 
 /*
@@ -120,7 +105,7 @@ SegmentIntersector::hasProperInteriorIntersection()
 bool
 SegmentIntersector::isTrivialIntersection(Edge *e0,int segIndex0,Edge *e1,int segIndex1)
 {
-//	if (e0->equals(e1)) {
+//	if (e0->equals(e1)) 
 	if (e0==e1) {
 		if (li->getIntersectionNum()==1) {
 			if (isAdjacentSegments(segIndex0,segIndex1))
@@ -147,7 +132,7 @@ void
 SegmentIntersector::addIntersections(Edge *e0,int segIndex0,Edge *e1,int segIndex1)
 {
 
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"SegmentIntersector::addIntersections() called"<<endl;
 #endif
 
@@ -180,7 +165,7 @@ SegmentIntersector::addIntersections(Edge *e0,int segIndex0,Edge *e1,int segInde
 		// only intersection.
 		if (!isTrivialIntersection(e0,segIndex0,e1,segIndex1))
 		{
-#if DEBUG
+#if GEOS_DEBUG
 			cerr<<"SegmentIntersector::addIntersections(): has !TrivialIntersection"<<endl;
 #endif // DEBUG_INTERSECT
 			hasIntersectionVar=true;
@@ -188,14 +173,14 @@ SegmentIntersector::addIntersections(Edge *e0,int segIndex0,Edge *e1,int segInde
 				//Debug.println(li);
 				e0->addIntersections(li,segIndex0,0);
 				e1->addIntersections(li,segIndex1,1);
-#if DEBUG
+#if GEOS_DEBUG
 				cerr<<"SegmentIntersector::addIntersections(): includeProper || !li->isProper()"<<endl;
 #endif // DEBUG_INTERSECT
 			}
 			if (li->isProper())
 			{
-				properIntersectionPoint.setCoordinate(li->getIntersection(0));
-#if DEBUG
+				properIntersectionPoint=li->getIntersection(0);
+#if GEOS_DEBUG
 				cerr<<"SegmentIntersector::addIntersections(): properIntersectionPoint: "<<properIntersectionPoint.toString()<<endl;
 #endif // DEBUG_INTERSECT
 				hasProper=true;
@@ -208,18 +193,13 @@ SegmentIntersector::addIntersections(Edge *e0,int segIndex0,Edge *e1,int segInde
 	}
 }
 
+/*private*/
 bool
-SegmentIntersector::isBoundaryPoint(LineIntersector *li,vector<vector<Node*>*> *tstBdyNodes)
+SegmentIntersector::isBoundaryPoint(LineIntersector *li,
+		vector<Node*> *tstBdyNodes)
 {
-	if (tstBdyNodes==NULL) return false;
-	if (isBoundaryPoint(li,(*tstBdyNodes)[0])) return true;
-	if (isBoundaryPoint(li,(*tstBdyNodes)[1])) return true;
-	return false;
-}
+	if ( ! tstBdyNodes ) return false;
 
-bool
-SegmentIntersector::isBoundaryPoint(LineIntersector *li,vector<Node*> *tstBdyNodes)
-{
 	for(vector<Node*>::iterator i=tstBdyNodes->begin();i<tstBdyNodes->end();i++) {
 		Node *node=*i;
 		const Coordinate& pt=node->getCoordinate();
@@ -227,10 +207,123 @@ SegmentIntersector::isBoundaryPoint(LineIntersector *li,vector<Node*> *tstBdyNod
 	}
 	return false;
 }
+
+
+/*private*/
+bool
+SegmentIntersector::isBoundaryPoint(LineIntersector *li,
+		vector<vector<Node*>*>& tstBdyNodes)
+{
+	if (isBoundaryPoint(li, tstBdyNodes[0])) return true;
+	if (isBoundaryPoint(li, tstBdyNodes[1])) return true;
+	return false;
 }
 
+} // namespace geos.geomgraph.index
+} // namespace geos.geomgraph
+} // namespace geos
+
 /**********************************************************************
- * $Log: SegmentIntersector.cpp,v $
+ * $Log$
+ * Revision 1.18  2006/03/23 13:31:58  strk
+ * Fixed to allow build with GEOS_DEBUG
+ *
+ * Revision 1.17  2006/03/15 17:16:31  strk
+ * streamlined headers inclusion
+ *
+ * Revision 1.16  2006/03/09 16:46:47  strk
+ * geos::geom namespace definition, first pass at headers split
+ *
+ * Revision 1.15  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.14  2006/03/02 12:12:00  strk
+ * Renamed DEBUG macros to GEOS_DEBUG, all wrapped in #ifndef block to allow global override (bug#43)
+ *
+ * Revision 1.13  2006/02/23 11:54:20  strk
+ * - MCIndexPointSnapper
+ * - MCIndexSnapRounder
+ * - SnapRounding BufferOp
+ * - ScaledNoder
+ * - GEOSException hierarchy cleanups
+ * - SpatialIndex memory-friendly query interface
+ * - GeometryGraph::getBoundaryNodes memory-friendly
+ * - NodeMap::getBoundaryNodes memory-friendly
+ * - Cleanups in geomgraph::Edge
+ * - Added an XML test for snaprounding buffer (shows leaks, working on it)
+ *
+ * Revision 1.12  2006/02/19 19:46:49  strk
+ * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
+ *
+ * Revision 1.11  2006/01/31 19:07:34  strk
+ * - Renamed DefaultCoordinateSequence to CoordinateArraySequence.
+ * - Moved GetNumGeometries() and GetGeometryN() interfaces
+ *   from GeometryCollection to Geometry class.
+ * - Added getAt(int pos, Coordinate &to) funtion to CoordinateSequence class.
+ * - Reworked automake scripts to produce a static lib for each subdir and
+ *   then link all subsystem's libs togheter
+ * - Moved C-API in it's own top-level dir capi/
+ * - Moved source/bigtest and source/test to tests/bigtest and test/xmltester
+ * - Fixed PointLocator handling of LinearRings
+ * - Changed CoordinateArrayFilter to reduce memory copies
+ * - Changed UniqueCoordinateArrayFilter to reduce memory copies
+ * - Added CGAlgorithms::isPointInRing() version working with
+ *   Coordinate::ConstVect type (faster!)
+ * - Ported JTS-1.7 version of ConvexHull with big attention to
+ *   memory usage optimizations.
+ * - Improved XMLTester output and user interface
+ * - geos::geom::util namespace used for geom/util stuff
+ * - Improved memory use in geos::geom::util::PolygonExtractor
+ * - New ShortCircuitedGeometryVisitor class
+ * - New operation/predicate package
+ *
+ * Revision 1.10  2005/11/21 16:03:20  strk
+ *
+ * Coordinate interface change:
+ *         Removed setCoordinate call, use assignment operator
+ *         instead. Provided a compile-time switch to
+ *         make copy ctor and assignment operators non-inline
+ *         to allow for more accurate profiling.
+ *
+ * Coordinate copies removal:
+ *         NodeFactory::createNode() takes now a Coordinate reference
+ *         rather then real value. This brings coordinate copies
+ *         in the testLeaksBig.xml test from 654818 to 645991
+ *         (tested in 2.1 branch). In the head branch Coordinate
+ *         copies are 222198.
+ *         Removed useless coordinate copies in ConvexHull
+ *         operations
+ *
+ * STL containers heap allocations reduction:
+ *         Converted many containers element from
+ *         pointers to real objects.
+ *         Made some use of .reserve() or size
+ *         initialization when final container size is known
+ *         in advance.
+ *
+ * Stateless classes allocations reduction:
+ *         Provided ::instance() function for
+ *         NodeFactories, to avoid allocating
+ *         more then one (they are all
+ *         stateless).
+ *
+ * HCoordinate improvements:
+ *         Changed HCoordinate constructor by HCoordinates
+ *         take reference rather then real objects.
+ *         Changed HCoordinate::intersection to avoid
+ *         a new allocation but rather return into a provided
+ *         storage. LineIntersector changed to reflect
+ *         the above change.
+ *
+ * Revision 1.9  2005/11/15 10:04:37  strk
+ *
+ * Reduced heap allocations (vectors, mostly).
+ * Enforced const-correctness, changed some interfaces
+ * to use references rather then pointers when appropriate.
+ *
+ * Revision 1.8  2005/04/06 11:09:41  strk
+ * Applied patch from Jon Schlueter (math.h => cmath; ieeefp.h in "C" block)
+ *
  * Revision 1.7  2004/11/23 19:53:06  strk
  * Had LineIntersector compute Z by interpolation.
  *
@@ -247,7 +340,7 @@ SegmentIntersector::isBoundaryPoint(LineIntersector *li,vector<Node*> *tstBdyNod
  * Revision 1.3  2004/07/08 19:34:49  strk
  * Mirrored JTS interface of CoordinateSequence, factory and
  * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
+ * Added CoordinateArraySequenceFactory::instance() function.
  *
  * Revision 1.2  2004/07/02 13:28:26  strk
  * Fixed all #include lines to reflect headers layout change.
