@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: unload.h,v 1.1 2004/07/02 13:20:42 strk Exp $
+ * $Id: unload.h 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -12,7 +12,13 @@
  * See the COPYING file for more information.
  *
  **********************************************************************
- * $Log: unload.h,v $
+ * $Log$
+ * Revision 1.3  2006/03/06 19:43:20  strk
+ * Fixed Unload class definition namespace (geos::io)
+ *
+ * Revision 1.2  2006/03/01 10:39:58  strk
+ * ctor and dtor made private and inlined
+ *
  * Revision 1.1  2004/07/02 13:20:42  strk
  * Header files moved under geos/ dir.
  *
@@ -28,14 +34,17 @@
 #define GEOS_UNLOAD_H
 //xie add for realse static memory 2003,10,06
 namespace geos {
+namespace io {
 
 class Unload
 {
+private:
+	Unload(void) {}
+	~Unload(void) {}
 public:
-	Unload(void);
-	~Unload(void);
 	static void Release();
 };
 
+}
 }
 #endif
