@@ -1,9 +1,10 @@
 /**********************************************************************
- * $Id: Quadtree.cpp,v 1.15 2004/12/08 13:54:43 strk Exp $
+ * $Id: Quadtree.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
+ * Copyright (C) 2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -11,23 +12,37 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
+ **********************************************************************
+ *
+ * Last port: index/quadtree/Quadtree.java rev. 1.14
+ *
  **********************************************************************/
 
-#include <geos/indexQuadtree.h>
-#include <geos/util.h>
+#include <geos/index/quadtree/Quadtree.h>
+#include <geos/geom/Envelope.h>
 
-#ifndef DEBUG
-#define DEBUG 0
+#include <vector>
+#include <cassert>
+
+#ifndef GEOS_DEBUG
+#define GEOS_DEBUG 0
 #endif
 
-namespace geos {
+#if GEOS_DEBUG
+#include <iostream>
+#endif
 
-/*
- * Ensure that the envelope for the inserted item has non-zero extents.
- * Use the current minExtent to pad the envelope, if necessary.
- * Can return a new Envelope or the given one.
- */
-Envelope* Quadtree::ensureExtent(const Envelope *itemEnv,double minExtent) {
+using namespace std;
+using namespace geos::geom;
+
+namespace geos {
+namespace index { // geos.index
+namespace quadtree { // geos.index.quadtree
+
+/*public static*/
+Envelope*
+Quadtree::ensureExtent(const Envelope *itemEnv, double minExtent)
+{
 	//The names "ensureExtent" and "minExtent" are misleading -- sounds like
 	//this method ensures that the extents are greater than minExtent.
 	//Perhaps we should rename them to "ensurePositiveExtent" and "defaultExtent".
@@ -51,24 +66,18 @@ Envelope* Quadtree::ensureExtent(const Envelope *itemEnv,double minExtent) {
 	return newEnv;
 }
 
-/**
-* Constructs a Quadtree with zero items.
-*/
-Quadtree::Quadtree(){
-	minExtent=1.0;
-	root=new QuadTreeRoot();
-}
-
-Quadtree::~Quadtree(){
+/*public*/
+Quadtree::~Quadtree()
+{
 	for (unsigned int i=0; i<newEnvelopes.size(); i++)
 		delete newEnvelopes[i];
 	delete root;
 }
 
-/**
-* Returns the number of levels in the tree.
-*/
-int Quadtree::depth() {
+/*public*/
+int
+Quadtree::depth()
+{
 	//I don't think it's possible for root to be null. Perhaps we should
 	//remove the check. [Jon Aquino]
     //Or make an assertion [Jon Aquino 10/29/2003] 
@@ -76,22 +85,24 @@ int Quadtree::depth() {
 	return 0;
 }
 
-/**
-* Returns the number of items in the tree.
-*/
-int Quadtree::size() {
-	if (root!=NULL) return root->size();
-	return 0;
+/*public*/
+int
+Quadtree::size()
+{
+	assert(root!=NULL);
+	return root->size();
 }
 
+/*public*/
 void
 Quadtree::insert(const Envelope *itemEnv, void* item)
 {
 	collectStats(itemEnv);
+
 	Envelope *insertEnv=ensureExtent(itemEnv,minExtent);
 	if ( insertEnv != itemEnv ) newEnvelopes.push_back(insertEnv);
 	root->insert(insertEnv,item);
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"Quadtree::insert("<<itemEnv->toString()<<", "<<item<<")"<<endl;
 	cerr<<"       insertEnv:"<<insertEnv->toString()<<endl;
 	cerr<<"       tree:"<<endl<<root->toString()<<endl;
@@ -99,32 +110,45 @@ Quadtree::insert(const Envelope *itemEnv, void* item)
 }
 
 
-vector<void*>*
-Quadtree::query(const Envelope *searchEnv)
+/*public*/
+void
+Quadtree::query(const Envelope *searchEnv,
+	vector<void*>& foundItems)
 {
 	/*
 	 * the items that are matched are the items in quads which
 	 * overlap the search envelope
 	 */
-	vector<void*> *foundItems=new vector<void*>();
-	root->addAllItemsFromOverlapping(searchEnv,foundItems);
-#if DEBUG
-	cerr<<"Quadtree::query returning "<<foundItems->size()<<" items over "<<size()<<" items in index (of depth: "<<depth()<<")"<<endl;
+	root->addAllItemsFromOverlapping(searchEnv, &foundItems);
+#if GEOS_DEBUG
+	cerr<<"Quadtree::query returning "<<foundItems.size()
+		<<" items over "<<size()
+		<<" items in index (of depth: "<<depth()<<")"<<endl;
 	cerr<<" Root:\n"<<root->toString()<<endl;
 #endif
-	return foundItems;
 }
 
-/**
- * Return a list of all items in the Quadtree
- */
-vector<void*>* Quadtree::queryAll() {
+/*public*/
+vector<void*>*
+Quadtree::queryAll()
+{
 	vector<void*> *foundItems=new vector<void*>();
 	root->addAllItems(foundItems);
 	return foundItems;
 }
 
-void Quadtree::collectStats(const Envelope *itemEnv){
+/*public*/
+bool
+Quadtree::remove(const Envelope* itemEnv, void* item)
+{
+	Envelope* posEnv = ensureExtent(itemEnv, minExtent);
+	return root->remove(posEnv, item);
+}
+
+/*private*/
+void
+Quadtree::collectStats(const Envelope *itemEnv)
+{
 	double delX=itemEnv->getWidth();
 	if (delX<minExtent && delX>0.0)
 		minExtent=delX;
@@ -133,6 +157,7 @@ void Quadtree::collectStats(const Envelope *itemEnv){
 		minExtent=delY;
 }
 
+/*public*/
 string
 Quadtree::toString() const
 {
@@ -140,46 +165,32 @@ Quadtree::toString() const
 	return ret;
 }
 
+} // namespace geos.index.quadtree
+} // namespace geos.index
 } // namespace geos
 
 /**********************************************************************
- * $Log: Quadtree.cpp,v $
- * Revision 1.15  2004/12/08 13:54:43  strk
- * gcc warnings checked and fixed, general cleanups.
+ * $Log$
+ * Revision 1.25  2006/04/03 08:29:30  strk
+ * Added port info, cleaned up log message, minor assertion checking.
  *
- * Revision 1.14  2004/11/01 16:43:04  strk
- * Added Profiler code.
- * Temporarly patched a bug in DoubleBits (must check drawbacks).
- * Various cleanups and speedups.
+ * Revision 1.24  2006/03/23 13:31:58  strk
+ * Fixed to allow build with GEOS_DEBUG
  *
- * Revision 1.13  2004/07/27 16:35:46  strk
- * Geometry::getEnvelopeInternal() changed to return a const Envelope *.
- * This should reduce object copies as once computed the envelope of a
- * geometry remains the same.
+ * Revision 1.23  2006/03/22 12:22:50  strk
+ * indexQuadtree.h split
  *
- * Revision 1.12  2004/07/13 08:33:52  strk
- * Added missing virtual destructor to virtual classes.
- * Fixed implicit unsigned int -> int casts
+ * Revision 1.22  2006/03/20 16:57:44  strk
+ * spatialindex.h and opValid.h headers split
  *
- * Revision 1.11  2004/07/02 13:28:27  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
+ * Revision 1.21  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
  *
- * Revision 1.10  2004/05/06 16:30:58  strk
- * Kept track of newly allocated objects by ensureExtent for Bintree and Quadtree,
- * deleted at destruction time. doc/example.cpp runs with no leaks.
- *
- * Revision 1.9  2004/04/19 15:14:45  strk
- * Added missing virtual destructor in SpatialIndex class.
- * Memory leaks fixes. Const and throw specifications added.
- *
- * Revision 1.8  2004/03/25 02:23:55  ybychkov
- * All "index/" packages upgraded to JTS 1.4
- *
- * Revision 1.7  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
+ * Revision 1.20  2006/03/02 12:12:00  strk
+ * Renamed DEBUG macros to GEOS_DEBUG, all wrapped in #ifndef block to allow global override (bug#43)
  *
+ * Revision 1.19  2006/03/01 13:49:45  strk
+ * Fixed debug lines (bug#36)
  *
  **********************************************************************/
 
