@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: WKBReader.cpp 2022 2007-09-14 15:25:29Z csavage $
+ * $Id: WKBReader.cpp 2227 2008-11-26 19:25:04Z pramsey $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -254,7 +254,7 @@ WKBReader::readGeometry()
 	bool hasSRID = ((typeInt & 0x20000000) != 0);
 
 #if DEBUG_WKB_READER
-	cout<<"WKB hasSRID: "<<hasZ<<endl;
+	cout<<"WKB hasSRID: "<<hasSRID<<endl;
 #endif
 
 	int SRID = 0;
@@ -303,7 +303,11 @@ Point *
 WKBReader::readPoint()
 {
 	readCoordinate();
-	return factory.createPoint(Coordinate(ordValues[0], ordValues[1]));
+	if(inputDimension == 3){
+	  return factory.createPoint(Coordinate(ordValues[0], ordValues[1], ordValues[2]));
+	}else{
+	  return factory.createPoint(Coordinate(ordValues[0], ordValues[1]));
+	}
 }
 
 LineString *
