@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: WKBWriter.cpp 2025 2007-09-21 17:32:05Z csavage $
+ * $Id: WKBWriter.cpp 2228 2008-11-26 19:27:17Z pramsey $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -48,6 +48,10 @@ WKBWriter::WKBWriter(int dims, int bo, bool srid):
 		throw util::IllegalArgumentException("WKB output dimension must be 2 or 3");
 }
 
+WKBWriter::~WKBWriter()
+{
+}
+
 void
 WKBWriter::writeHEX(const Geometry &g, ostream &os) 
 {
@@ -248,7 +252,7 @@ WKBWriter::writeCoordinate(const CoordinateSequence &cs, int idx,
 	if ( is3d )
 	{
 		ByteOrderValues::putDouble(
-			cs.getOrdinate(idx, CoordinateSequence::X),
+			cs.getOrdinate(idx, CoordinateSequence::Z),
 			buf, byteOrder);
 		outStream->write(reinterpret_cast<char *>(buf), 8);
 	}
