@@ -1,9 +1,10 @@
 /**********************************************************************
- * $Id: LineBuilder.cpp,v 1.18 2004/12/08 13:54:44 strk Exp $
+ * $Id: LineBuilder.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
+ * Copyright (C) 2005-2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -13,27 +14,49 @@
  *
  **********************************************************************/
 
-#include <geos/opOverlay.h>
-#include <geos/io.h>
-#include <stdio.h>
+#include <map>
+#include <vector>
+#include <cassert>
 
-#define DEBUG 0
+#include <geos/operation/overlay/LineBuilder.h>
+#include <geos/operation/overlay/OverlayOp.h>
+
+#include <geos/algorithm/PointLocator.h>
+
+#include <geos/geom/GeometryFactory.h>
+
+#include <geos/geomgraph/Node.h>
+#include <geos/geomgraph/Edge.h>
+#include <geos/geomgraph/DirectedEdge.h>
+#include <geos/geomgraph/DirectedEdgeStar.h>
+
+#ifndef GEOS_DEBUG
+#define GEOS_DEBUG 0
+#endif
 #define COMPUTE_Z 1
 
-namespace geos {
+using namespace std;
+using namespace geos::algorithm;
+using namespace geos::geomgraph;
+using namespace geos::geom;
 
-LineBuilder::LineBuilder(OverlayOp *newOp, const GeometryFactory *newGeometryFactory, PointLocator *newPtLocator)
+namespace geos {
+namespace operation { // geos.operation
+namespace overlay { // geos.operation.overlay
+
+LineBuilder::LineBuilder(OverlayOp *newOp,
+		const GeometryFactory *newGeometryFactory,
+		PointLocator *newPtLocator):
+	op(newOp),
+	geometryFactory(newGeometryFactory),
+	ptLocator(newPtLocator),
+	//lineEdgesList(new vector<Edge *>()),
+	resultLineList(new vector<LineString *>())
 {
-	op=newOp;
-	geometryFactory=newGeometryFactory;
-	ptLocator=newPtLocator;
-	lineEdgesList=new vector<Edge*>();
-	resultLineList=new vector<LineString*>();
 }
 
 LineBuilder::~LineBuilder()
 {
-	delete lineEdgesList;
 }
 
 /*
@@ -41,11 +64,11 @@ LineBuilder::~LineBuilder()
  *         specified overlay operation
  */
 vector<LineString*>*
-LineBuilder::build(int opCode)
+LineBuilder::build(OverlayOp::OpCode opCode)
 {
 	findCoveredLineEdges();
 	collectLines(opCode);
-	//labelIsolatedLines(lineEdgesList);
+	//labelIsolatedLines(&lineEdgesList);
 	buildLines(opCode);
 	return resultLineList;
 }
@@ -61,21 +84,28 @@ void
 LineBuilder::findCoveredLineEdges()
 {
 // first set covered for all L edges at nodes which have A edges too
-	map<Coordinate,Node*,CoordLT> *nodeMap=op->getGraph()->getNodeMap()->nodeMap;
-	map<Coordinate,Node*,CoordLT>::iterator	it=nodeMap->begin();
-	for (;it!=nodeMap->end();it++) {
+	map<Coordinate*,Node*,CoordinateLessThen> &nodeMap=op->getGraph().getNodeMap()->nodeMap;
+	map<Coordinate*,Node*,CoordinateLessThen>::iterator it=nodeMap.begin();
+	map<Coordinate*,Node*,CoordinateLessThen>::iterator endIt=nodeMap.end();
+	for ( ; it!=endIt; ++it)
+	{
 		Node *node=it->second;
 		//node.print(System.out);
-		((DirectedEdgeStar*)node->getEdges())->findCoveredLineEdges();
+		assert(dynamic_cast<DirectedEdgeStar*>(node->getEdges()));
+		DirectedEdgeStar* des=static_cast<DirectedEdgeStar*>(node->getEdges());
+		des->findCoveredLineEdges();
+		//((DirectedEdgeStar*)node->getEdges())->findCoveredLineEdges();
 	}
 
 	/*
 	 * For all L edges which weren't handled by the above,
 	 * use a point-in-poly test to determine whether they are covered
 	 */
-	vector<EdgeEnd*> *ee=op->getGraph()->getEdgeEnds();
-	for(int i=0;i<(int)ee->size();i++) {
-		DirectedEdge *de=(DirectedEdge*) (*ee)[i];
+	vector<EdgeEnd*> *ee=op->getGraph().getEdgeEnds();
+	for(size_t i=0, s=ee->size(); i<s; ++i)
+	{
+		assert(dynamic_cast<DirectedEdge*>((*ee)[i]));
+		DirectedEdge *de=static_cast<DirectedEdge*>((*ee)[i]);
 		Edge *e=de->getEdge();
 		if (de->isLineEdge() && !e->isCoveredSet()) {
 			bool isCovered=op->isCoveredByA(de->getCoordinate());
@@ -85,24 +115,30 @@ LineBuilder::findCoveredLineEdges()
 }
 
 void
-LineBuilder::collectLines(int opCode)
+LineBuilder::collectLines(OverlayOp::OpCode opCode)
 {
-	vector<EdgeEnd*> *ee=op->getGraph()->getEdgeEnds();
-	for(int i=0;i<(int)ee->size();i++) {
-		DirectedEdge *de=(DirectedEdge*) (*ee)[i];
-		collectLineEdge(de,opCode,lineEdgesList);
-		collectBoundaryTouchEdge(de,opCode,lineEdgesList);
+	vector<EdgeEnd*> *ee=op->getGraph().getEdgeEnds();
+	for(size_t i=0, s=ee->size(); i<s; ++i)
+	{
+		assert(dynamic_cast<DirectedEdge*>((*ee)[i]));
+		DirectedEdge *de=static_cast<DirectedEdge*>((*ee)[i]);
+		collectLineEdge(de, opCode, &lineEdgesList);
+		collectBoundaryTouchEdge(de, opCode, &lineEdgesList);
 	}
 }
 
 void
-LineBuilder::collectLineEdge(DirectedEdge *de,int opCode,vector<Edge*> *edges)
+LineBuilder::collectLineEdge(DirectedEdge *de, OverlayOp::OpCode opCode,
+		vector<Edge*> *edges)
 {
 	Label *label=de->getLabel();
 	Edge *e=de->getEdge();
 	// include L edges which are in the result
 	if (de->isLineEdge()) {
-		if (!de->isVisited() && OverlayOp::isResultOfOp(label,opCode) && !e->isCovered()) {
+		if (!de->isVisited()
+			&& OverlayOp::isResultOfOp(label,opCode)
+			&& !e->isCovered())
+		{
 			//Debug.println("de: "+de.getLabel());
 			//Debug.println("edge: "+e.getLabel());
 			edges->push_back(e);
@@ -120,7 +156,8 @@ LineBuilder::collectLineEdge(DirectedEdge *de,int opCode,vector<Edge*> *edges)
  *  - OR as a result of a dimensional collapse.
  */
 void
-LineBuilder::collectBoundaryTouchEdge(DirectedEdge *de,int opCode,vector<Edge*> *edges)
+LineBuilder::collectBoundaryTouchEdge(DirectedEdge *de,
+		OverlayOp::OpCode opCode, vector<Edge*> *edges)
 {
 	Label *label=de->getLabel();
 	// this smells like a bit of a hack, but it seems to work...
@@ -128,19 +165,21 @@ LineBuilder::collectBoundaryTouchEdge(DirectedEdge *de,int opCode,vector<Edge*>
 		&& !de->isInteriorAreaEdge()  // added to handle dimensional collapses
 		&& !de->getEdge()->isInResult()
 		&& !de->isVisited()
-		&& OverlayOp::isResultOfOp(label,opCode)
-		&& opCode==OverlayOp::INTERSECTION) {
+		&& OverlayOp::isResultOfOp(label, opCode)
+		&& opCode==OverlayOp::opINTERSECTION)
+	{
 			edges->push_back(de->getEdge());
 			de->setVisitedEdge(true);
 	}
 }
 
 void
-LineBuilder::buildLines(int opCode)
+LineBuilder::buildLines(OverlayOp::OpCode /* opCode */)
 {
 	// need to simplify lines?
-	for(int i=0;i<(int)lineEdgesList->size();i++) {
-		Edge *e=(*lineEdgesList)[i];
+	for(size_t i=0, s=lineEdgesList.size(); i<s; ++i)
+	{
+		Edge *e=lineEdgesList[i];
 		//Label *label=e->getLabel();
 		CoordinateSequence *cs = e->getCoordinates()->clone();
 #if COMPUTE_Z
@@ -161,25 +200,25 @@ LineBuilder::buildLines(int opCode)
 void
 LineBuilder::propagateZ(CoordinateSequence *cs)
 {
-	unsigned int i;
-#if DEBUG
+	size_t i;
+#if GEOS_DEBUG
 	cerr<<"LineBuilder::propagateZ() called"<<endl;
 #endif
 
 	vector<int>v3d; // vertex 3d
-	unsigned int cssize = cs->getSize();
+	size_t cssize = cs->getSize();
 	for (i=0; i<cssize; i++)
 	{
 		if ( !ISNAN(cs->getAt(i).z) ) v3d.push_back(i);
 	}
 
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"  found "<<v3d.size()<<" 3d vertexes"<<endl;
 #endif
 	
 	if ( v3d.size() == 0 )
 	{
-#if DEBUG
+#if GEOS_DEBUG
 		cerr<<"  nothing to do"<<endl;
 #endif
 		return;
@@ -200,7 +239,7 @@ LineBuilder::propagateZ(CoordinateSequence *cs)
 	}
 
 	// interpolate inbetweens
-	unsigned int prev=v3d[0];
+	size_t prev=v3d[0];
 	for (i=1; i<v3d.size(); i++)
 	{
 		int curr=v3d[i];
@@ -227,7 +266,7 @@ LineBuilder::propagateZ(CoordinateSequence *cs)
 	if ( prev < cssize-1 )
 	{
 		double z = cs->getAt(prev).z;
-		for (unsigned int j=prev+1; j<cssize; j++)
+		for (size_t j=prev+1; j<cssize; j++)
 		{
 			buf = cs->getAt(j);
 			buf.z = z;
@@ -242,7 +281,8 @@ LineBuilder::propagateZ(CoordinateSequence *cs)
 void
 LineBuilder::labelIsolatedLines(vector<Edge*> *edgesList)
 {
-	for(int i=0;i<(int)edgesList->size();i++) {
+	for(size_t i=0, s=edgesList->size(); i<s; ++i)
+	{
 		Edge *e=(*edgesList)[i];
 		Label *label=e->getLabel();
 		//n.print(System.out);
@@ -259,16 +299,51 @@ LineBuilder::labelIsolatedLines(vector<Edge*> *edgesList)
  * Label an isolated node with its relationship to the target geometry.
  */
 void
-LineBuilder::labelIsolatedLine(Edge *e,int targetIndex)
+LineBuilder::labelIsolatedLine(Edge *e, int targetIndex)
 {
 	int loc=ptLocator->locate(e->getCoordinate(),op->getArgGeometry(targetIndex));
 	e->getLabel()->setLocation(targetIndex,loc);
 }
 
-}
+} // namespace geos.operation.overlay
+} // namespace geos.operation
+} // namespace geos
 
 /**********************************************************************
- * $Log: LineBuilder.cpp,v $
+ * $Log$
+ * Revision 1.28  2006/06/13 22:19:39  strk
+ * fixed unused parameter warning
+ *
+ * Revision 1.27  2006/06/12 11:29:24  strk
+ * unsigned int => size_t
+ *
+ * Revision 1.26  2006/06/05 15:36:34  strk
+ * Given OverlayOp funx code enum a name and renamed values to have a lowercase prefix. Drop all of noding headers from installed header set.
+ *
+ * Revision 1.25  2006/03/20 16:57:44  strk
+ * spatialindex.h and opValid.h headers split
+ *
+ * Revision 1.24  2006/03/17 13:24:59  strk
+ * opOverlay.h header splitted. Reduced header inclusions in operation/overlay implementation files. ElevationMatrixFilter code moved from own file to ElevationMatrix.cpp (ideally a class-private).
+ *
+ * Revision 1.23  2006/03/02 12:12:01  strk
+ * Renamed DEBUG macros to GEOS_DEBUG, all wrapped in #ifndef block to allow global override (bug#43)
+ *
+ * Revision 1.22  2006/02/19 19:46:49  strk
+ * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
+ *
+ * Revision 1.21  2005/12/08 00:03:51  strk
+ * LineBuilder::lineEdgesList made a real vector, rather then pointer (private member).
+ * Small optimizations in LineBuilder loops, cleanups in LineBuilder class dox.
+ *
+ * Revision 1.20  2005/11/15 12:14:05  strk
+ * Reduced heap allocations, made use of references when appropriate,
+ * small optimizations here and there.
+ *
+ * Revision 1.19  2005/02/05 05:44:47  strk
+ * Changed geomgraph nodeMap to use Coordinate pointers as keys, reduces
+ * lots of other Coordinate copies.
+ *
  * Revision 1.18  2004/12/08 13:54:44  strk
  * gcc warnings checked and fixed, general cleanups.
  *
