@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: OverlayOp.cpp 1932 2006-12-05 10:42:05Z strk $
+ * $Id: OverlayOp.cpp 2220 2008-11-11 17:32:38Z pramsey $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -685,18 +685,25 @@ OverlayOp::computeOverlay(OverlayOp::OpCode opCode)
 		// Will throw TopologyException if noding is found to be invalid
 		EdgeNodingValidator nv(edgeList.getEdges());
 
-#ifdef GEOS_DEBUG_VALIDATION // {
 		try {
 			nv.checkValid();
 		} catch (const util::TopologyException& ex) {
+#ifdef GEOS_DEBUG_VALIDATION // {
 			cout << "EdgeNodingValidator found noding invalid: " << ex.what() << endl;
+#endif // }
+                        // In the error scenario, the edgeList is not properly
+                        // deleted. Cannot add to the destructor of EdgeList
+                        // (as it should) because 
+                        // "graph.addEdges(edgeList.getEdges());" below
+                        // takes over edgeList ownership in the success case.
+                        edgeList.clearList();
+
 			throw ex;
 		}
+#ifdef GEOS_DEBUG_VALIDATION // {
 		cout << "EdgeNodingValidator accepted the noding" << endl;
-
-#else // }{
-		nv.checkValid();
 #endif // }
+
 	}
 #ifdef GEOS_DEBUG_VALIDATION // {
 	else
@@ -898,7 +905,6 @@ OverlayOp::checkObviouslyWrongResult(OverlayOp::OpCode opCode)
 
 	assert(resultGeom);
 
-
 #ifdef ENABLE_OTHER_OVERLAY_RESULT_VALIDATORS
 
 	if ( opCode == opINTERSECTION
@@ -947,6 +953,9 @@ OverlayOp::checkObviouslyWrongResult(OverlayOp::OpCode opCode)
 	}
 
 	// Add your tests here
+
+#else
+    UNREFERENCED_PARAMETER(opCode);
 #endif
 
 #ifdef ENABLE_OVERLAY_RESULT_VALIDATOR
