@@ -1,9 +1,10 @@
 /**********************************************************************
- * $Id: PolygonizeGraph.cpp,v 1.8.4.2 2005/12/09 11:36:45 strk Exp $
+ * $Id: PolygonizeGraph.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
+ * Copyright (C) 2005-2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -13,28 +14,48 @@
  *
  **********************************************************************/
 
+#include <geos/operation/polygonize/PolygonizeGraph.h>
+#include <geos/operation/polygonize/PolygonizeDirectedEdge.h>
+#include <geos/operation/polygonize/PolygonizeEdge.h>
+#include <geos/operation/polygonize/EdgeRing.h>
+#include <geos/planargraph/Node.h>
+#include <geos/planargraph/DirectedEdgeStar.h>
+#include <geos/planargraph/DirectedEdge.h>
+#include <geos/geom/CoordinateSequence.h>
+#include <geos/geom/LineString.h>
 
-#include <geos/opPolygonize.h>
-#include <geos/util.h>
+#include <cassert>
+#include <vector>
+
+//using namespace std;
+using namespace geos::planargraph;
+using namespace geos::geom;
 
 namespace geos {
+namespace operation { // geos.operation
+namespace polygonize { // geos.operation.polygonize
 
-int PolygonizeGraph::getDegreeNonDeleted(planarNode *node) {
-	vector<planarDirectedEdge*> *edges=node->getOutEdges()->getEdges();
+int
+PolygonizeGraph::getDegreeNonDeleted(Node *node)
+{
+	std::vector<DirectedEdge*> &edges=node->getOutEdges()->getEdges();
 	int degree=0;
-	for(int i=0;i<(int)edges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*) (*edges)[i];
-		if (!de->isMarked()) degree++;
+	for(unsigned int i=0; i<edges.size(); ++i) {
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)edges[i];
+		if (!de->isMarked()) ++degree;
 	}
 	return degree;
 }
 
-int PolygonizeGraph::getDegree(planarNode *node, long label){
-	vector<planarDirectedEdge*> *edges=node->getOutEdges()->getEdges();
+int
+PolygonizeGraph::getDegree(Node *node, long label)
+{
+	std::vector<DirectedEdge*> &edges=node->getOutEdges()->getEdges();
 	int degree=0;
-	for(int i=0;i<(int)edges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*) (*edges)[i];
-		if (de->getLabel()==label) degree++;
+	for(unsigned int i=0; i<edges.size(); ++i)
+	{
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)edges[i];
+		if (de->getLabel()==label) ++degree;
 	}
 	return degree;
 }
@@ -43,11 +64,11 @@ int PolygonizeGraph::getDegree(planarNode *node, long label){
  * Deletes all edges at a node
  */
 void
-PolygonizeGraph::deleteAllEdges(planarNode *node)
+PolygonizeGraph::deleteAllEdges(Node *node)
 {
-	vector<planarDirectedEdge*> *edges=node->getOutEdges()->getEdges();
-	for(int i=0;i<(int)edges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*) (*edges)[i];
+	std::vector<DirectedEdge*> &edges=node->getOutEdges()->getEdges();
+	for(unsigned int i=0; i<edges.size(); ++i) {
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)edges[i];
 		de->setMarked(true);
 		PolygonizeDirectedEdge *sym=(PolygonizeDirectedEdge*) de->getSym();
 		if (sym!=NULL)
@@ -58,9 +79,9 @@ PolygonizeGraph::deleteAllEdges(planarNode *node)
 /*
  * Create a new polygonization graph.
  */
-PolygonizeGraph::PolygonizeGraph(const GeometryFactory *newFactory)
+PolygonizeGraph::PolygonizeGraph(const GeometryFactory *newFactory):
+	factory(newFactory)
 {
-	factory=newFactory;
 }
 
 /*
@@ -103,13 +124,14 @@ PolygonizeGraph::addEdge(const LineString *line)
 
 	const Coordinate& startPt=linePts->getAt(0);
 	const Coordinate& endPt=linePts->getAt(linePts->getSize()-1);
-	planarNode *nStart=getNode(startPt);
-	planarNode *nEnd=getNode(endPt);
-	planarDirectedEdge *de0=new PolygonizeDirectedEdge(nStart, nEnd, linePts->getAt(1), true);
+	Node *nStart=getNode(startPt);
+	Node *nEnd=getNode(endPt);
+	DirectedEdge *de0=new PolygonizeDirectedEdge(nStart, nEnd, linePts->getAt(1), true);
 	newDirEdges.push_back(de0);
-	planarDirectedEdge *de1=new PolygonizeDirectedEdge(nEnd, nStart, linePts->getAt(linePts->getSize()-2), false);
+	DirectedEdge *de1=new PolygonizeDirectedEdge(nEnd, nStart,
+			linePts->getAt(linePts->getSize()-2), false);
 	newDirEdges.push_back(de1);
-	planarEdge *edge=new PolygonizeEdge(line);
+	Edge *edge=new PolygonizeEdge(line);
 	newEdges.push_back(edge);
 	edge->setDirectedEdges(de0, de1);
 	add(edge);
@@ -117,12 +139,12 @@ PolygonizeGraph::addEdge(const LineString *line)
 	newCoords.push_back(linePts);
 }
 
-planarNode *
+Node *
 PolygonizeGraph::getNode(const Coordinate& pt)
 {
-	planarNode *node=findNode(pt);
+	Node *node=findNode(pt);
 	if (node==NULL) {
-		node=new planarNode(pt);
+		node=new Node(pt);
 		newNodes.push_back(node);
 		// ensure node is only added once to graph
 		add(node);
@@ -133,10 +155,10 @@ PolygonizeGraph::getNode(const Coordinate& pt)
 void
 PolygonizeGraph::computeNextCWEdges()
 {
-	vector<planarNode*> *pns=getNodes();
+	std::vector<Node*> *pns=getNodes();
 	// set the next pointers for the edges around each node
 	for(int i=0;i<(int)pns->size();i++) {
-		planarNode *node=(*pns)[i];
+		Node *node=(*pns)[i];
 		computeNextCWEdges(node);
 	}
 	delete pns;
@@ -149,22 +171,22 @@ PolygonizeGraph::computeNextCWEdges()
  * @param ringEdges the list of start edges for the edgeRings to convert.
  */
 void
-PolygonizeGraph::convertMaximalToMinimalEdgeRings(vector<PolygonizeDirectedEdge*> *ringEdges)
+PolygonizeGraph::convertMaximalToMinimalEdgeRings(std::vector<PolygonizeDirectedEdge*> *ringEdges)
 {
 	for(int i=0;i<(int)ringEdges->size();i++)
 	{
 		PolygonizeDirectedEdge *de=(*ringEdges)[i];
 		long label=de->getLabel();
-		vector<planarNode*> *intNodes=findIntersectionNodes(de, label);
+		std::vector<Node*> *intNodes=findIntersectionNodes(de, label);
 		if (intNodes==NULL) continue;
 
 		// flip the next pointers on the intersection nodes to
 		// create minimal edge rings
-		//vector<planarNode*> *pns=getNodes();
+		//std::vector<Node*> *pns=getNodes();
 
 		// set the next pointers for the edges around each node
 		for(int j=0;j<(int)intNodes->size();j++) {
-			planarNode *node=(*intNodes)[j];
+			Node *node=(*intNodes)[j];
 			computeNextCCWEdges(node, label);
 		}
 
@@ -180,21 +202,21 @@ PolygonizeGraph::convertMaximalToMinimalEdgeRings(vector<PolygonizeDirectedEdge*
  * or <code>NULL</code> if no intersection nodes were found.
  * Ownership of returned object goes to caller.
  */
-vector<planarNode*>*
+std::vector<Node*>*
 PolygonizeGraph::findIntersectionNodes(PolygonizeDirectedEdge *startDE, long label)
 {
 	PolygonizeDirectedEdge *de=startDE;
-	vector<planarNode*> *intNodes=NULL;
+	std::vector<Node*> *intNodes=NULL;
 	do {
-		planarNode *node=de->getFromNode();
+		Node *node=de->getFromNode();
 		if (getDegree(node, label) > 1) {
 			if (intNodes==NULL)
-				intNodes=new vector<planarNode*>();
+				intNodes=new std::vector<Node*>();
 			intNodes->push_back(node);
 		}
 		de=de->getNext();
-		Assert::isTrue(de!=NULL, "found NULL DE in ring");
-		Assert::isTrue(de==startDE || !de->isInRing(), "found DE already in ring");
+		assert(de!=NULL); // found NULL DE in ring
+		assert(de==startDE || !de->isInRing()); // found DE already in ring
 	} while (de!=startDE);
 	return intNodes;
 }
@@ -203,7 +225,7 @@ PolygonizeGraph::findIntersectionNodes(PolygonizeDirectedEdge *startDE, long lab
  * Computes the EdgeRings formed by the edges in this graph.
  * @return a list of the EdgeRing found by the polygonization process.
  */
-vector<polygonizeEdgeRing*>*
+std::vector<EdgeRing*>*
 PolygonizeGraph::getEdgeRings()
 {
 	// maybe could optimize this, since most of these pointers should
@@ -212,18 +234,19 @@ PolygonizeGraph::getEdgeRings()
 	computeNextCWEdges();
 
 	// clear labels of all edges in graph
-	label(dirEdges,-1);
-	vector<PolygonizeDirectedEdge*> *maximalRings=findLabeledEdgeRings(dirEdges);
+	label(dirEdges, -1);
+	std::vector<PolygonizeDirectedEdge*> *maximalRings=findLabeledEdgeRings(dirEdges);
 	convertMaximalToMinimalEdgeRings(maximalRings);
 	delete maximalRings;
 
 	// find all edgerings
-	vector<polygonizeEdgeRing*> *edgeRingList=new vector<polygonizeEdgeRing*>();
-	for(int i=0;i<(int)dirEdges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)(*dirEdges)[i];
+	std::vector<EdgeRing*> *edgeRingList=new std::vector<EdgeRing*>();
+	for(unsigned int i=0; i<dirEdges.size(); ++i)
+	{
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)dirEdges[i];
 		if (de->isMarked()) continue;
 		if (de->isInRing()) continue;
-		polygonizeEdgeRing *er=findEdgeRing(de);
+		EdgeRing *er=findEdgeRing(de);
 		edgeRingList->push_back(er);
 	}
 	return edgeRingList;
@@ -234,21 +257,22 @@ PolygonizeGraph::getEdgeRings()
 * @param dirEdges a List of the DirectedEdges in the graph
 * @return a List of DirectedEdges, one for each edge ring found
 */
-vector<PolygonizeDirectedEdge*>*
-PolygonizeGraph::findLabeledEdgeRings(vector<planarDirectedEdge*> *dirEdges)
+std::vector<PolygonizeDirectedEdge*>*
+PolygonizeGraph::findLabeledEdgeRings(std::vector<DirectedEdge*> &dirEdges)
 {
-	vector<PolygonizeDirectedEdge*> *edgeRingStarts=new vector<PolygonizeDirectedEdge*>();
+	std::vector<PolygonizeDirectedEdge*> *edgeRingStarts=new std::vector<PolygonizeDirectedEdge*>();
 	// label the edge rings formed
 	long currLabel=1;
-	for(int i=0;i<(int)dirEdges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)(*dirEdges)[i];
+	for(unsigned int i=0; i<dirEdges.size(); ++i)
+	{
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)dirEdges[i];
 		if (de->isMarked()) continue;
 		if (de->getLabel() >= 0) continue;
 		edgeRingStarts->push_back(de);
-		vector<planarDirectedEdge*> *edges=findDirEdgesInRing(de);
-		label(edges, currLabel);
+		std::vector<DirectedEdge*> *edges=findDirEdgesInRing(de);
+		label(*edges, currLabel);
 		delete edges;
-		currLabel++;
+		++currLabel;
 	}
 	return edgeRingStarts;
 }
@@ -257,7 +281,7 @@ PolygonizeGraph::findLabeledEdgeRings(vector<planarDirectedEdge*> *dirEdges)
  * Finds and removes all cut edges from the graph.
  * @return a list of the LineString forming the removed cut edges
  */
-vector<const LineString*> *
+std::vector<const LineString*> *
 PolygonizeGraph::deleteCutEdges()
 {
 	computeNextCWEdges();
@@ -269,9 +293,9 @@ PolygonizeGraph::deleteCutEdges()
 	 * Cut Edges are edges where both dirEdges have the same label.
 	 * Delete them, and record them
 	 */
-	vector<const LineString*> *cutLines=new vector<const LineString*>();
-	for(int i=0;i<(int)dirEdges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)(*dirEdges)[i];
+	std::vector<const LineString*> *cutLines=new std::vector<const LineString*>();
+	for(unsigned int i=0; i<dirEdges.size(); ++i) {
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)dirEdges[i];
 		if (de->isMarked()) continue;
 		PolygonizeDirectedEdge *sym=(PolygonizeDirectedEdge*) de->getSym();
 		if (de->getLabel()==sym->getLabel()) {
@@ -285,22 +309,27 @@ PolygonizeGraph::deleteCutEdges()
 	return cutLines;
 }
 
-void PolygonizeGraph::label(vector<planarDirectedEdge*> *dirEdges, long label){
-	for(int i=0;i<(int)dirEdges->size();i++) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)(*dirEdges)[i];
+void
+PolygonizeGraph::label(std::vector<DirectedEdge*> &dirEdges, long label)
+{
+	for(unsigned int i=0; i<dirEdges.size(); ++i)
+	{
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)dirEdges[i];
 		de->setLabel(label);
 	}
 }
 
-void PolygonizeGraph::computeNextCWEdges(planarNode *node){
-	planarDirectedEdgeStar *deStar=node->getOutEdges();
+void
+PolygonizeGraph::computeNextCWEdges(Node *node)
+{
+	DirectedEdgeStar *deStar=node->getOutEdges();
 	PolygonizeDirectedEdge *startDE=NULL;
 	PolygonizeDirectedEdge *prevDE=NULL;
 
 	// the edges are stored in CCW order around the star
-	vector<planarDirectedEdge*> *pde=deStar->getEdges();
-	for(int i=0;i<(int)pde->size();i++) {
-		PolygonizeDirectedEdge *outDE=(PolygonizeDirectedEdge*)(*pde)[i];
+	std::vector<DirectedEdge*> &pde=deStar->getEdges();
+	for(unsigned int i=0; i<pde.size(); ++i) {
+		PolygonizeDirectedEdge *outDE=(PolygonizeDirectedEdge*)pde[i];
 		if (outDE->isMarked()) continue;
 		if (startDE==NULL)
 			startDE=outDE;
@@ -315,20 +344,30 @@ void PolygonizeGraph::computeNextCWEdges(planarNode *node){
 		sym->setNext(startDE);
 	}
 }
+
 /**
-* Computes the next edge pointers going CCW around the given node, for the
-* given edgering label.
-* This algorithm has the effect of converting maximal edgerings into minimal edgerings
-*/
-void PolygonizeGraph::computeNextCCWEdges(planarNode *node, long label) {
-	planarDirectedEdgeStar *deStar=node->getOutEdges();
+ * Computes the next edge pointers going CCW around the given node, for the
+ * given edgering label.
+ * This algorithm has the effect of converting maximal edgerings into
+ * minimal edgerings
+ */
+void
+PolygonizeGraph::computeNextCCWEdges(Node *node, long label)
+{
+	DirectedEdgeStar *deStar=node->getOutEdges();
 	PolygonizeDirectedEdge *firstOutDE=NULL;
 	PolygonizeDirectedEdge *prevInDE=NULL;
 
 	// the edges are stored in CCW order around the star
-	vector<planarDirectedEdge*> *edges=deStar->getEdges();
-	for(int i=(int)edges->size()-1;i>=0;i--) {
-		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)(*edges)[i];
+	std::vector<DirectedEdge*> &edges=deStar->getEdges();
+
+	/*
+	 * Must use a SIGNED int here to allow for beak condition
+	 * to be true.
+	 */
+	for(int i=edges.size()-1; i>=0; --i)
+	{
+		PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)edges[i];
 		PolygonizeDirectedEdge *sym=(PolygonizeDirectedEdge*) de->getSym();
 		PolygonizeDirectedEdge *outDE=NULL;
 		if (de->getLabel()==label) outDE=de;
@@ -348,7 +387,7 @@ void PolygonizeGraph::computeNextCCWEdges(planarNode *node, long label) {
 		}
 	}
 	if (prevInDE != NULL) {
-		Assert::isTrue(firstOutDE != NULL);
+		assert(firstOutDE != NULL);
 		prevInDE->setNext(firstOutDE);
 	}
 }
@@ -361,33 +400,33 @@ void PolygonizeGraph::computeNextCCWEdges(planarNode *node, long label) {
  * @param startDE the DirectedEdge to start traversing at
  * @return a List of DirectedEdges that form a ring
  */
-vector<planarDirectedEdge*>*
+std::vector<DirectedEdge*>*
 PolygonizeGraph::findDirEdgesInRing(PolygonizeDirectedEdge *startDE)
 {
 	PolygonizeDirectedEdge *de=startDE;
-	vector<planarDirectedEdge*> *edges=new vector<planarDirectedEdge*>();
+	std::vector<DirectedEdge*> *edges=new std::vector<DirectedEdge*>();
 	do {
 		edges->push_back(de);
 		de=de->getNext();
-		Assert::isTrue(de != NULL, "found NULL DE in ring");
-		Assert::isTrue(de==startDE || !de->isInRing(), "found DE already in ring");
+		assert(de != NULL); // found NULL DE in ring
+		assert(de==startDE || !de->isInRing()); // found DE already in ring
 	} while (de != startDE);
 	return edges;
 }
 
-polygonizeEdgeRing *
+EdgeRing *
 PolygonizeGraph::findEdgeRing(PolygonizeDirectedEdge *startDE)
 {
 	PolygonizeDirectedEdge *de=startDE;
-	polygonizeEdgeRing *er=new polygonizeEdgeRing(factory);
-	// Now, when will we delete those polygonizeEdgeRings ?
+	EdgeRing *er=new EdgeRing(factory);
+	// Now, when will we delete those EdgeRings ?
 	newEdgeRings.push_back(er);
 	do {
 		er->add(de);
 		de->setRing(er);
 		de=de->getNext();
-		Assert::isTrue(de != NULL, "found NULL DE in ring");
-		Assert::isTrue(de==startDE || ! de->isInRing(), "found DE already in ring");
+		assert(de != NULL); // found NULL DE in ring
+		assert(de==startDE || ! de->isInRing()); // found DE already in ring
 	} while (de != startDE);
 	return er;
 }
@@ -402,23 +441,24 @@ PolygonizeGraph::findEdgeRing(PolygonizeDirectedEdge *startDE)
  *
  * @return a List containing the LineStrings that formed dangles
  */
-vector<const LineString*>*
+std::vector<const LineString*>*
 PolygonizeGraph::deleteDangles()
 {
-	vector<planarNode*> *nodesToRemove=findNodesOfDegree(1);
-	vector<const LineString*> *dangleLines=new vector<const LineString*>();
-	vector<planarNode*> nodeStack;
+	std::vector<Node*> *nodesToRemove=findNodesOfDegree(1);
+	std::vector<const LineString*> *dangleLines=new std::vector<const LineString*>();
+	std::vector<Node*> nodeStack;
 	for(int i=0;i<(int)nodesToRemove->size();i++) {
 		nodeStack.push_back((*nodesToRemove)[i]);
 	}
 	delete nodesToRemove;
 	while (!nodeStack.empty()) {
-		planarNode *node=nodeStack[nodeStack.size()-1];
+		Node *node=nodeStack[nodeStack.size()-1];
 		nodeStack.pop_back();
 		deleteAllEdges(node);
-		vector<planarDirectedEdge*> *nodeOutEdges=node->getOutEdges()->getEdges();
-		for(int j=0;j<(int)nodeOutEdges->size();j++) {
-			PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*) (*nodeOutEdges)[j];
+		std::vector<DirectedEdge*> &nodeOutEdges=node->getOutEdges()->getEdges();
+		for(unsigned int j=0; j<nodeOutEdges.size(); ++j)
+		{
+			PolygonizeDirectedEdge *de=(PolygonizeDirectedEdge*)nodeOutEdges[j];
 			// delete this edge and its sym
 			de->setMarked(true);
 			PolygonizeDirectedEdge *sym=(PolygonizeDirectedEdge*) de->getSym();
@@ -427,7 +467,7 @@ PolygonizeGraph::deleteDangles()
 			// save the line as a dangle
 			PolygonizeEdge *e=(PolygonizeEdge*) de->getEdge();
 			dangleLines->push_back(e->getLine());
-			planarNode *toNode=de->getToNode();
+			Node *toNode=de->getToNode();
 			// add the toNode to the list to be processed, if it is now a dangle
 			if (getDegreeNonDeleted(toNode)==1)
 				nodeStack.push_back(toNode);
@@ -435,18 +475,100 @@ PolygonizeGraph::deleteDangles()
 	}
 	return dangleLines;
 }
-}
+
+} // namespace geos.operation.polygonize
+} // namespace geos.operation
+} // namespace geos
 
 /**********************************************************************
- * $Log: PolygonizeGraph.cpp,v $
- * Revision 1.8.4.2  2005/12/09 11:36:45  strk
+ * $Log$
+ * Revision 1.18  2006/03/22 11:19:06  strk
+ * opPolygonize.h headers split.
+ *
+ * Revision 1.17  2006/03/21 21:42:54  strk
+ * planargraph.h header split, planargraph:: classes renamed to match JTS symbols
+ *
+ * Revision 1.16  2006/03/06 19:40:47  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
+ *
+ * Revision 1.15  2006/03/03 10:46:22  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.14  2006/02/19 19:46:49  strk
+ * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
+ *
+ * Revision 1.13  2006/01/31 19:07:34  strk
+ * - Renamed DefaultCoordinateSequence to CoordinateArraySequence.
+ * - Moved GetNumGeometries() and GetGeometryN() interfaces
+ *   from GeometryCollection to Geometry class.
+ * - Added getAt(int pos, Coordinate &to) funtion to CoordinateSequence class.
+ * - Reworked automake scripts to produce a static lib for each subdir and
+ *   then link all subsystem's libs togheter
+ * - Moved C-API in it's own top-level dir capi/
+ * - Moved source/bigtest and source/test to tests/bigtest and test/xmltester
+ * - Fixed PointLocator handling of LinearRings
+ * - Changed CoordinateArrayFilter to reduce memory copies
+ * - Changed UniqueCoordinateArrayFilter to reduce memory copies
+ * - Added CGAlgorithms::isPointInRing() version working with
+ *   Coordinate::ConstVect type (faster!)
+ * - Ported JTS-1.7 version of ConvexHull with big attention to
+ *   memory usage optimizations.
+ * - Improved XMLTester output and user interface
+ * - geos::geom::util namespace used for geom/util stuff
+ * - Improved memory use in geos::geom::util::PolygonExtractor
+ * - New ShortCircuitedGeometryVisitor class
+ * - New operation/predicate package
+ *
+ * Revision 1.12  2005/12/09 11:36:38  strk
  * Small leak plugged in CAPI::GEOSHasZ() and in
  * invalid input to PolygonizeGraph (again)
  *
- * Revision 1.8.4.1  2005/12/09 10:04:52  strk
+ * Revision 1.11  2005/12/09 10:03:46  strk
  * Fixed a bug making PolygonizeGraph choking on invalid LineStrings.
  * Minor optimizations in Polygonizer loops.
  *
+ * Revision 1.10  2005/11/21 16:03:20  strk
+ *
+ * Coordinate interface change:
+ *         Removed setCoordinate call, use assignment operator
+ *         instead. Provided a compile-time switch to
+ *         make copy ctor and assignment operators non-inline
+ *         to allow for more accurate profiling.
+ *
+ * Coordinate copies removal:
+ *         NodeFactory::createNode() takes now a Coordinate reference
+ *         rather then real value. This brings coordinate copies
+ *         in the testLeaksBig.xml test from 654818 to 645991
+ *         (tested in 2.1 branch). In the head branch Coordinate
+ *         copies are 222198.
+ *         Removed useless coordinate copies in ConvexHull
+ *         operations
+ *
+ * STL containers heap allocations reduction:
+ *         Converted many containers element from
+ *         pointers to real objects.
+ *         Made some use of .reserve() or size
+ *         initialization when final container size is known
+ *         in advance.
+ *
+ * Stateless classes allocations reduction:
+ *         Provided ::instance() function for
+ *         NodeFactories, to avoid allocating
+ *         more then one (they are all
+ *         stateless).
+ *
+ * HCoordinate improvements:
+ *         Changed HCoordinate constructor by HCoordinates
+ *         take reference rather then real objects.
+ *         Changed HCoordinate::intersection to avoid
+ *         a new allocation but rather return into a provided
+ *         storage. LineIntersector changed to reflect
+ *         the above change.
+ *
+ * Revision 1.9  2005/11/15 12:14:05  strk
+ * Reduced heap allocations, made use of references when appropriate,
+ * small optimizations here and there.
+ *
  * Revision 1.8  2004/12/14 10:35:44  strk
  * Comments cleanup. PolygonizeGraph keeps track of generated CoordinateSequence
  * for delayed destruction.
@@ -470,7 +592,7 @@ PolygonizeGraph::deleteDangles()
  * Revision 1.3  2004/07/08 19:34:50  strk
  * Mirrored JTS interface of CoordinateSequence, factory and
  * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
+ * Added CoordinateArraySequenceFactory::instance() function.
  *
  * Revision 1.2  2004/07/02 13:28:29  strk
  * Fixed all #include lines to reflect headers layout change.
