@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: IsValidOp.cpp 1820 2006-09-06 16:54:23Z mloskot $
+ * $Id: IsValidOp.cpp 2210 2008-10-23 17:33:16Z warmerdam $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -111,6 +111,8 @@ void
 IsValidOp::checkValid(const Geometry *g)
 {
 	if (isChecked) return;
+
+        assert( validErr == NULL );
 	validErr=NULL;
 
 	// empty geometries are always valid!
@@ -126,6 +128,7 @@ IsValidOp::checkValid(const Geometry *g)
 	else if ((gc=dynamic_cast<const GeometryCollection *>(g)))
 		checkValid(gc);
 	else throw util::UnsupportedOperationException();
+        isChecked=true;
 }
 
 /*
