@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: CommonBitsRemover.cpp 1820 2006-09-06 16:54:23Z mloskot $
+ * $Id: CommonBitsRemover.cpp 2127 2008-05-20 21:25:21Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -20,6 +20,7 @@
 #include <geos/geom/CoordinateFilter.h>
 #include <geos/geom/Coordinate.h>
 #include <geos/geom/Geometry.h>
+#include <geos/util.h>
 
 #include <cassert>
 
@@ -49,7 +50,11 @@ public:
 		trans(newTrans)
 	{}
 
-	void filter_ro(const geom::Coordinate *coord){ assert(0); }; //Not used
+	void filter_ro(const geom::Coordinate *coord)  //Not used
+    {
+        UNREFERENCED_PARAMETER(coord);
+        assert(0);
+    };
 
 	void filter_rw(geom::Coordinate *coord) const
 	{
@@ -67,7 +72,8 @@ public:
 
 	void filter_rw(geom::Coordinate *coord) const
 	{
-		// CommonCoordinateFilter is a read-only filter
+        // CommonCoordinateFilter is a read-only filter
+        UNREFERENCED_PARAMETER(coord);
 		assert(0);
 	}
 
