@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: GeometricShapeFactory.cpp,v 1.8 2004/12/08 13:54:44 strk Exp $
+ * $Id: GeometricShapeFactory.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,11 +13,25 @@
  *
  **********************************************************************/
 
-#include <geos/geom.h>
-#include <geos/util.h>
-#include <stdio.h>
+#include <geos/util/GeometricShapeFactory.h>
+#include <geos/geom/Coordinate.h>
+#include <geos/geom/CoordinateSequenceFactory.h>
+#include <geos/geom/GeometryFactory.h>
+#include <geos/geom/PrecisionModel.h>
+#include <geos/geom/Envelope.h>
+
+#include <vector>
+#include <cmath>
+
+#ifndef M_PI
+#define M_PI        3.14159265358979323846
+#endif
+
+using namespace std;
+using namespace geos::geom;
 
 namespace geos {
+namespace util { // geos.util
 
 /*
  * Create a shape factory which will create shapes using the given
@@ -103,7 +117,7 @@ Polygon* GeometricShapeFactory::createRectangle(){
 	double YsegLen = env->getHeight() / nSide;
 
 	vector<Coordinate> *vc = new vector<Coordinate>(4*nSide+1);
-	//CoordinateSequence* pts=new DefaultCoordinateSequence(4*nSide+1);
+	//CoordinateSequence* pts=new CoordinateArraySequence(4*nSide+1);
 
 	//double maxx = env->getMinX() + nSide * XsegLen;
 	//double maxy = env->getMinY() + nSide * XsegLen;
@@ -216,9 +230,11 @@ LineString* GeometricShapeFactory::createArc(double startAng,double endAng){
 	return line;
 }
 
-GeometricShapeFactory::Dimensions::Dimensions()  {
-	base=Coordinate::nullCoord;
-	centre=Coordinate::nullCoord;
+GeometricShapeFactory::Dimensions::Dimensions()
+	:
+	base(Coordinate::getNull()),
+	centre(Coordinate::getNull())
+{
 }
 
 void GeometricShapeFactory::Dimensions::setBase(const Coordinate& newBase)  {
@@ -242,52 +258,25 @@ void GeometricShapeFactory::Dimensions::setHeight(double nHeight) {
 }
 
 Envelope* GeometricShapeFactory::Dimensions::getEnvelope() {
-	if (base!=Coordinate::nullCoord) {
+	if (base!=Coordinate::getNull()) {
 		return new Envelope(base.x, base.x + width, base.y, base.y + height);
 	}
-	if (centre!=Coordinate::nullCoord) {
+	if (centre!=Coordinate::getNull()) {
 		return new Envelope(centre.x - width/2, centre.x + width/2,centre.y - height/2, centre.y + height/2);
 	}
 	return new Envelope(0, width, 0, height);
 }
 
+} // namespace geos.util
 } // namespace geos
 
 /**********************************************************************
- * $Log: GeometricShapeFactory.cpp,v $
- * Revision 1.8  2004/12/08 13:54:44  strk
- * gcc warnings checked and fixed, general cleanups.
- *
- * Revision 1.7  2004/07/16 10:28:41  strk
- * Dimesions object allocated on the heap
- *
- * Revision 1.6  2004/07/15 13:40:44  strk
- * Memory leaks fixed, CoordinateSequence use made JTS - compatible.
- *
- * Revision 1.5  2004/07/14 21:19:35  strk
- * GeometricShapeFactory first pass of bug fixes
- *
- * Revision 1.4  2004/07/08 19:34:50  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.3  2004/07/02 13:28:29  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.2  2004/07/01 14:12:44  strk
- *
- * Geometry constructors come now in two flavors:
- * 	- deep-copy args (pass-by-reference)
- * 	- take-ownership of args (pass-by-pointer)
- * Same functionality is available through GeometryFactory,
- * including buildGeometry().
- *
- * Revision 1.1  2004/03/18 10:42:44  ybychkov
- * "IO" and "Util" upgraded to JTS 1.4
- * "Geometry" partially upgraded.
- *
+ * $Log$
+ * Revision 1.15  2006/03/22 16:58:35  strk
+ * Removed (almost) all inclusions of geom.h.
+ * Removed obsoleted .cpp files.
+ * Fixed a bug in WKTReader not using the provided CoordinateSequence
+ * implementation, optimized out some memory allocations.
  *
  **********************************************************************/
 
