@@ -1,4 +1,4 @@
-// $Id: GEOSSimplifyTest.cpp 1937 2006-12-05 11:22:48Z mloskot $
+// $Id: GEOSSimplifyTest.cpp 2164 2008-08-18 23:30:00Z mloskot $
 // 
 // Test Suite for C-API GEOSSimplify
 
@@ -21,6 +21,9 @@ namespace tut
     // Common data used in test cases.
     struct test_capigeossimplify_data
 	{
+	    GEOSGeometry* geom1_;
+	    GEOSGeometry* geom2_;
+
 		static void notice(const char *fmt, ...)
 		{
 			std::fprintf( stdout, "NOTICE: ");
@@ -34,12 +37,17 @@ namespace tut
 		}
 
 		test_capigeossimplify_data()
+            : geom1_(0), geom2_(0)
 		{
 			initGEOS(notice, notice);
 		}		
 
 		~test_capigeossimplify_data()
 		{
+            GEOSGeom_destroy(geom1_);
+            GEOSGeom_destroy(geom2_);
+            geom1_ = 0;
+            geom2_ = 0;
 			finishGEOS();
 		}
 
@@ -59,13 +67,13 @@ namespace tut
     template<>
     void object::test<1>()
     {
-	    GEOSGeometry* geom1 = GEOSGeomFromWKT("POLYGON EMPTY");
+	    geom1_ = GEOSGeomFromWKT("POLYGON EMPTY");
 
-		ensure ( 0 != GEOSisEmpty(geom1) );
+		ensure ( 0 != GEOSisEmpty(geom1_) );
 
-		GEOSGeometry* geom2 = GEOSSimplify(geom1, 43.2);
+		geom2_ = GEOSSimplify(geom1_, 43.2);
 
-		ensure ( 0 != GEOSisEmpty(geom2) );
+		ensure ( 0 != GEOSisEmpty(geom2_) );
     }
     
 } // namespace tut
